from _typeshed import Incomplete

class OrganizationLinks:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        _self: Incomplete | None = None,
        members: Incomplete | None = None,
        owners: Incomplete | None = None,
        labels: Incomplete | None = None,
        secrets: Incomplete | None = None,
        buckets: Incomplete | None = None,
        tasks: Incomplete | None = None,
        dashboards: Incomplete | None = None,
    ) -> None: ...
    @property
    def members(self): ...
    @members.setter
    def members(self, members) -> None: ...
    @property
    def owners(self): ...
    @owners.setter
    def owners(self, owners) -> None: ...
    @property
    def labels(self): ...
    @labels.setter
    def labels(self, labels) -> None: ...
    @property
    def secrets(self): ...
    @secrets.setter
    def secrets(self, secrets) -> None: ...
    @property
    def buckets(self): ...
    @buckets.setter
    def buckets(self, buckets) -> None: ...
    @property
    def tasks(self): ...
    @tasks.setter
    def tasks(self, tasks) -> None: ...
    @property
    def dashboards(self): ...
    @dashboards.setter
    def dashboards(self, dashboards) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from hvac.api.vault_api_base import VaultApiBase

logger: Incomplete

class Kv(VaultApiBase):
    allowed_kv_versions: Incomplete
    def __init__(self, adapter, default_kv_version: str = "2") -> None: ...
    @property
    def v1(self): ...
    @property
    def v2(self): ...
    @property
    def default_kv_version(self): ...
    @default_kv_version.setter
    def default_kv_version(self, default_kv_version) -> None: ...
    def __getattr__(self, item): ...



from _typeshed import Incomplete

from ..cmd import Command

class build_py(Command):
    description: str
    user_options: Incomplete
    boolean_options: Incomplete
    negative_opt: Incomplete
    build_lib: Incomplete
    py_modules: Incomplete
    package: Incomplete
    package_data: Incomplete
    package_dir: Incomplete
    compile: int
    optimize: int
    force: Incomplete
    def initialize_options(self) -> None: ...
    packages: Incomplete
    data_files: Incomplete
    def finalize_options(self) -> None: ...
    def run(self) -> None: ...
    def get_data_files(self): ...
    def find_data_files(self, package, src_dir): ...
    def build_package_data(self) -> None: ...
    def get_package_dir(self, package): ...
    def check_package(self, package, package_dir): ...
    def check_module(self, module, module_file): ...
    def find_package_modules(self, package, package_dir): ...
    def find_modules(self): ...
    def find_all_modules(self): ...
    def get_source_files(self): ...
    def get_module_outfile(self, build_dir, package, module): ...
    def get_outputs(self, include_bytecode: int = ...): ...
    def build_module(self, module, module_file, package): ...
    def build_modules(self) -> None: ...
    def build_packages(self) -> None: ...
    def byte_compile(self, files) -> None: ...



from hashlib import _Hash
from typing import Final, Literal
from typing_extensions import TypeAlias

from pyasn1.type.namedtype import NamedTypes
from pyasn1.type.univ import Sequence

PBE_WITH_SHA1_AND_TRIPLE_DES_CBC_OID: Final[tuple[int, ...]]
PURPOSE_KEY_MATERIAL: Final = 1
PURPOSE_IV_MATERIAL: Final = 2
PURPOSE_MAC_MATERIAL: Final = 3

_Purpose: TypeAlias = Literal[1, 2, 3]

class Pkcs12PBEParams(Sequence):
    componentType: NamedTypes

def derive_key(
    hashfn: _Hash, purpose_byte: _Purpose, password_str: str, salt: bytes, iteration_count: int, desired_key_size: int
) -> bytes: ...
def decrypt_PBEWithSHAAnd3KeyTripleDESCBC(
    data: bytes | bytearray, password_str: str, salt: bytes, iteration_count: int
) -> bytes: ...
def decrypt_PBEWithSHAAndTwofishCBC(
    encrypted_data: bytes | bytearray, password: str, salt: bytes, iteration_count: int
) -> bytes: ...
def encrypt_PBEWithSHAAndTwofishCBC(
    plaintext_data: bytes | bytearray, password: str, salt: bytes, iteration_count: int
) -> bytes: ...



from xml.dom.pulldom import DOMEventStream

from .expatreader import DefusedExpatParser

__origin__: str

def parse(
    stream_or_string,
    parser: DefusedExpatParser | None = None,
    bufsize: int | None = None,
    forbid_dtd: bool = False,
    forbid_entities: bool = True,
    forbid_external: bool = True,
) -> DOMEventStream: ...
def parseString(
    string: str,
    parser: DefusedExpatParser | None = None,
    forbid_dtd: bool = False,
    forbid_entities: bool = True,
    forbid_external: bool = True,
) -> DOMEventStream: ...



from .croniter import (
    CroniterBadCronError as CroniterBadCronError,
    CroniterBadDateError as CroniterBadDateError,
    CroniterBadTypeRangeError as CroniterBadTypeRangeError,
    CroniterNotAlphaError as CroniterNotAlphaError,
    CroniterUnsupportedSyntaxError as CroniterUnsupportedSyntaxError,
    croniter as croniter,
    croniter_range as croniter_range,
    datetime_to_timestamp as datetime_to_timestamp,
)



# Can't generate with stubgen because `import pywintypes` must be called first.
# Otherwise you get the error: "KeyError: 'pywintypes'"
from _typeshed import Incomplete
from collections.abc import Sequence
from datetime import datetime
from typing import ClassVar, Final, NoReturn, SupportsInt, overload
from typing_extensions import Never, TypeAlias, deprecated

import _win32typing

class error(Exception):
    winerror: int
    funcname: str
    strerror: str
    def __init__(self, winerror: int, funcname: str, strerror: str, /): ...

class com_error(Exception): ...

UnicodeType: TypeAlias = str

class HANDLEType:
    def __init__(self, *args: Never) -> NoReturn: ...
    @property
    def handle(self) -> int: ...
    def Close(self) -> None: ...
    def close(self) -> None: ...
    def Detach(self) -> None: ...
    def __int__(self) -> int: ...

class TimeType(datetime):  # aka: PyTime, PyDateTime
    __name__: ClassVar[str] = "datetime"
    Format = datetime.strftime

IIDType = _win32typing.PyIID

def DosDateTimeToTime(FatDate: int, FatTime: int, /) -> TimeType: ...
def Unicode() -> str: ...
def UnicodeFromRaw(_str: str, /) -> str: ...
def IsTextUnicode(_str: str, flags, /) -> tuple[Incomplete, Incomplete]: ...
def OVERLAPPED() -> _win32typing.PyOVERLAPPED: ...
def IID(iidString: str, is_bytes: bool = ..., /) -> _win32typing.PyIID: ...
def Time(timeRepr: SupportsInt | Sequence[SupportsInt] | TimeType, /) -> TimeType: ...
def CreateGuid() -> _win32typing.PyIID: ...
def ACL(bufSize: int = ..., /) -> _win32typing.PyACL: ...
def SID(buffer, idAuthority, subAuthorities, bufSize=..., /) -> _win32typing.PySID: ...
def SECURITY_ATTRIBUTES() -> _win32typing.PySECURITY_ATTRIBUTES: ...
def SECURITY_DESCRIPTOR() -> _win32typing.PySECURITY_DESCRIPTOR: ...
def HANDLE() -> HANDLEType: ...
def HKEY() -> _win32typing.PyHKEY: ...
def WAVEFORMATEX() -> _win32typing.PyWAVEFORMATEX: ...
@overload
@deprecated("Support for passing two ints to create a 64-bit value is deprecated; pass a single int instead")
def TimeStamp(timestamp: tuple[int, int], /) -> TimeType: ...
@overload
def TimeStamp(timestamp: int, /) -> TimeType: ...

FALSE: Final = False
TRUE: Final = True
WAVE_FORMAT_PCM: int



from typing import ClassVar

import passlib.utils.handlers as uh

class _MD5_Common(uh.HasSalt, uh.GenericHandler):
    checksum_size: ClassVar[int]
    checksum_chars: ClassVar[str]
    max_salt_size: ClassVar[int]
    salt_chars: ClassVar[str]
    @classmethod
    def from_string(cls, hash): ...

class md5_crypt(uh.HasManyBackends, _MD5_Common):
    name: ClassVar[str]
    ident: ClassVar[str]
    backends: ClassVar[tuple[str, ...]]

class apr_md5_crypt(_MD5_Common):
    name: ClassVar[str]
    ident: ClassVar[str]



from _typeshed import _BufferWithLen
from socket import socket
from typing import Literal, TypeVar, overload

from Xlib import error
from Xlib._typing import ErrorHandler
from Xlib.display import _ResourceBaseClass, _ResourceBaseClassesType
from Xlib.protocol import rq
from Xlib.support import lock
from Xlib.xobject import colormap, cursor, drawable, fontable, resource

_T = TypeVar("_T")

class bytesview:
    view: memoryview
    @overload
    def __init__(self, data: bytes | bytesview, offset: int, size: int) -> None: ...
    @overload
    def __init__(self, data: _BufferWithLen, offset: int = 0, size: int | None = None) -> None: ...
    @overload
    def __getitem__(self, key: slice) -> bytes: ...
    @overload
    def __getitem__(self, key: int) -> int: ...
    def __len__(self) -> int: ...

class Display:
    extension_major_opcodes: dict[str, int]
    error_classes: dict[int, type[error.XError]]
    event_classes: dict[int, type[rq.Event] | dict[int, type[rq.Event]]]
    resource_classes: _ResourceBaseClassesType | None
    display_name: str
    default_screen: int
    socket: socket
    socket_error_lock: lock._DummyLock
    socket_error: Exception | None
    event_queue_read_lock: lock._DummyLock
    event_queue_write_lock: lock._DummyLock
    event_queue: list[rq.Event]
    request_queue_lock: lock._DummyLock
    request_serial: int
    request_queue: list[tuple[rq.Request | rq.ReplyRequest | ConnectionSetupRequest, int]]
    send_recv_lock: lock._DummyLock
    send_active: int
    recv_active: int
    event_waiting: int
    event_wait_lock: lock._DummyLock
    request_waiting: int
    request_wait_lock: lock._DummyLock
    recv_buffer_size: int
    sent_requests: list[rq.Request | rq.ReplyRequest | ConnectionSetupRequest]
    recv_packet_len: int
    data_send: bytes
    data_recv: bytes
    data_sent_bytes: int
    resource_id_lock: lock._DummyLock
    resource_ids: dict[int, None]
    last_resource_id: int
    error_handler: ErrorHandler[object] | None
    big_endian: bool
    info: ConnectionSetupRequest
    def __init__(self, display: str | None = None) -> None: ...
    def get_display_name(self) -> str: ...
    def get_default_screen(self) -> int: ...
    def fileno(self) -> int: ...
    def next_event(self) -> rq.Event: ...
    def pending_events(self) -> int: ...
    def flush(self) -> None: ...
    def close(self) -> None: ...
    def set_error_handler(self, handler: ErrorHandler[object] | None) -> None: ...
    def allocate_resource_id(self) -> int: ...
    def free_resource_id(self, rid: int) -> None: ...
    @overload
    def get_resource_class(self, class_name: Literal["resource"], default: object = None) -> type[resource.Resource]: ...
    @overload
    def get_resource_class(self, class_name: Literal["drawable"], default: object = None) -> type[drawable.Drawable]: ...
    @overload
    def get_resource_class(self, class_name: Literal["window"], default: object = None) -> type[drawable.Window]: ...
    @overload
    def get_resource_class(self, class_name: Literal["pixmap"], default: object = None) -> type[drawable.Pixmap]: ...
    @overload
    def get_resource_class(self, class_name: Literal["fontable"], default: object = None) -> type[fontable.Fontable]: ...
    @overload
    def get_resource_class(self, class_name: Literal["font"], default: object = None) -> type[fontable.Font]: ...
    @overload
    def get_resource_class(self, class_name: Literal["gc"], default: object = None) -> type[fontable.GC]: ...
    @overload
    def get_resource_class(self, class_name: Literal["colormap"], default: object = None) -> type[colormap.Colormap]: ...
    @overload
    def get_resource_class(self, class_name: Literal["cursor"], default: object) -> type[cursor.Cursor]: ...
    @overload
    def get_resource_class(self, class_name: str, default: _T) -> type[_ResourceBaseClass] | _T: ...
    @overload
    def get_resource_class(self, class_name: str, default: None = None) -> type[_ResourceBaseClass] | None: ...
    def set_extension_major(self, extname: str, major: int) -> None: ...
    def get_extension_major(self, extname: str) -> int: ...
    def add_extension_event(self, code: int, evt: type[rq.Event], subcode: int | None = None) -> None: ...
    def add_extension_error(self, code: int, err: type[error.XError]) -> None: ...
    def check_for_error(self) -> None: ...
    def send_request(self, request: rq.Request | rq.ReplyRequest | ConnectionSetupRequest, wait_for_response: bool) -> None: ...
    def close_internal(self, whom: object) -> None: ...
    def send_and_recv(self, flush: bool = False, event: bool = False, request: int | None = None, recv: bool = False) -> None: ...
    def parse_response(self, request: int) -> bool: ...
    def parse_error_response(self, request: int) -> bool: ...
    def default_error_handler(self, err: object) -> None: ...
    def parse_request_response(self, request: int) -> bool: ...
    def parse_event_response(self, etype: int) -> None: ...
    def get_waiting_request(self, sno: int) -> rq.ReplyRequest | ConnectionSetupRequest | None: ...
    def get_waiting_replyrequest(self) -> rq.ReplyRequest | ConnectionSetupRequest: ...
    def parse_connection_setup(self) -> bool: ...

PixmapFormat: rq.Struct
VisualType: rq.Struct
Depth: rq.Struct
Screen: rq.Struct

class ConnectionSetupRequest(rq.GetAttrData):
    def __init__(self, display: Display, *args: object, **keys: object) -> None: ...



import sys
from _typeshed import Unused
from collections.abc import Callable, Generator, Iterable, Iterator, Sequence
from typing import Any, Literal, NoReturn, overload
from typing_extensions import Self

import numpy
from _cffi_backend import _CDataBase
from numpy.typing import NDArray

# Aka jack_position_t
# Actual type: _cffi_backend.__CDataOwn <cdata 'struct _jack_position *'>
# This is not a real subclassing. Just ensuring type-checkers sees this type as compatible with _CDataBase
# pyright has no error code for subclassing final
class _JackPositionT(_CDataBase):  # type: ignore[misc]  # pyright: ignore
    audio_frames_per_video_frame: float
    bar: int
    bar_start_tick: float
    bbt_offset: int
    beat: int
    beat_type: float
    beats_per_bar: float
    beats_per_minute: float
    frame: int
    frame_rate: int
    frame_time: float
    next_time: float
    padding: _CDataBase  # <cdata 'int32_t[7]'>
    tick: int
    ticks_per_beat: float
    unique_1: int
    unique_2: int
    usecs: int
    valid: int
    video_offset: int

class _CBufferType:
    @overload
    def __getitem__(self, key: int) -> str: ...
    @overload
    def __getitem__(self, key: slice) -> bytes: ...
    @overload
    def __setitem__(self, key: int, val: str) -> None: ...
    @overload
    def __setitem__(self, key: slice, val: bytes) -> None: ...
    def __len__(self) -> int: ...
    def __bytes__(self) -> bytes: ...

STOPPED: int
ROLLING: int
STARTING: int
NETSTARTING: int
PROPERTY_CREATED: int
PROPERTY_CHANGED: int
PROPERTY_DELETED: int
POSITION_BBT: int
POSITION_TIMECODE: int
POSITION_BBT_FRAME_OFFSET: int
POSITION_AUDIO_VIDEO_RATIO: int
POSITION_VIDEO_FRAME_OFFSET: int

class JackError(Exception): ...

class JackErrorCode(JackError):
    def __init__(self, message: str, code: int) -> None: ...
    message: str
    code: int

class JackOpenError(JackError):
    def __init__(self, name: str, status: Status) -> None: ...
    name: str
    status: Status

class Client:
    def __init__(
        self,
        name: str,
        use_exact_name: bool = False,
        no_start_server: bool = False,
        servername: str | None = None,
        session_id: str | None = None,
    ) -> None: ...
    def __enter__(self) -> Self: ...
    def __exit__(self, *args: Unused) -> None: ...
    def __del__(self) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def uuid(self) -> str: ...
    @property
    def samplerate(self) -> int: ...
    @property
    def blocksize(self) -> int: ...
    @blocksize.setter
    def blocksize(self, blocksize: int) -> None: ...
    @property
    def status(self) -> Status: ...
    @property
    def realtime(self) -> bool: ...
    @property
    def frames_since_cycle_start(self) -> int: ...
    @property
    def frame_time(self) -> int: ...
    @property
    def last_frame_time(self) -> int: ...
    @property
    def inports(self) -> Ports: ...
    @property
    def outports(self) -> Ports: ...
    @property
    def midi_inports(self) -> Ports: ...
    @property
    def midi_outports(self) -> Ports: ...
    def owns(self, port: str | Port) -> bool: ...
    def activate(self) -> None: ...
    def deactivate(self, ignore_errors: bool = True) -> None: ...
    def cpu_load(self) -> float: ...
    def close(self, ignore_errors: bool = True) -> None: ...
    def connect(self, source: str | Port, destination: str | Port) -> None: ...
    def disconnect(self, source: str | Port, destination: str | Port) -> None: ...
    def transport_start(self) -> None: ...
    def transport_stop(self) -> None: ...
    @property
    def transport_state(self) -> TransportState: ...
    @property
    def transport_frame(self) -> int: ...
    @transport_frame.setter
    def transport_frame(self, frame: int) -> None: ...
    def transport_locate(self, frame: int) -> None: ...
    def transport_query(self) -> tuple[TransportState, dict[str, Any]]: ...  # Anyof[int, float, _CDataBase]
    def transport_query_struct(self) -> tuple[TransportState, _JackPositionT]: ...
    def transport_reposition_struct(self, position: _JackPositionT) -> None: ...
    def set_sync_timeout(self, timeout: int) -> None: ...
    def set_freewheel(self, onoff: bool) -> None: ...
    def set_shutdown_callback(self, callback: Callable[[Status, str], object]) -> None: ...
    def set_process_callback(self, callback: Callable[[int], object]) -> None: ...
    def set_freewheel_callback(self, callback: Callable[[bool], object]) -> None: ...
    def set_blocksize_callback(self, callback: Callable[[int], object]) -> None: ...
    def set_samplerate_callback(self, callback: Callable[[int], object]) -> None: ...
    def set_client_registration_callback(self, callback: Callable[[str, bool], object]) -> None: ...
    def set_port_registration_callback(
        self, callback: Callable[[Port, bool], object] | None = None, only_available: bool = True
    ) -> None: ...
    def set_port_connect_callback(
        self, callback: Callable[[Port, Port, bool], object] | None = None, only_available: bool = True
    ) -> None: ...
    def set_port_rename_callback(
        self, callback: Callable[[Port, str, str], object] | None = None, only_available: bool = True
    ) -> None: ...
    def set_graph_order_callback(self, callback: Callable[[], object]) -> None: ...
    def set_xrun_callback(self, callback: Callable[[float], object]) -> None: ...
    def set_sync_callback(self, callback: Callable[[int, _JackPositionT], object] | None) -> None: ...
    def release_timebase(self) -> None: ...
    def set_timebase_callback(
        self, callback: Callable[[int, int, _JackPositionT, bool], object] | None = None, conditional: bool = False
    ) -> bool: ...
    def set_property_change_callback(self, callback: Callable[[int, str, int], object]) -> None: ...
    def get_uuid_for_client_name(self, name: str) -> str: ...
    def get_client_name_by_uuid(self, uuid: str) -> str: ...
    def get_port_by_name(self, name: str) -> Port: ...
    def get_all_connections(self, port: Port) -> list[Port]: ...
    def get_ports(
        self,
        name_pattern: str = "",
        is_audio: bool = False,
        is_midi: bool = False,
        is_input: bool = False,
        is_output: bool = False,
        is_physical: bool = False,
        can_monitor: bool = False,
        is_terminal: bool = False,
    ) -> list[Port]: ...
    def set_property(self, subject: int | str, key: str, value: str | bytes, type: str = "") -> None: ...
    def remove_property(self, subject: int | str, key: str) -> None: ...
    def remove_properties(self, subject: int | str) -> int: ...
    def remove_all_properties(self) -> None: ...

class Port:
    # <cdata 'struct _jack_port *'>
    def __init__(self, port_ptr: _CDataBase, client: Client) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    @property
    def name(self) -> str: ...
    @property
    def shortname(self) -> str: ...
    @shortname.setter
    def shortname(self, shortname: str) -> None: ...
    @property
    def aliases(self) -> list[str]: ...
    def set_alias(self, alias: str) -> None: ...
    def unset_alias(self, alias: str) -> None: ...
    @property
    def uuid(self) -> str: ...
    @property
    def is_audio(self) -> bool: ...
    @property
    def is_midi(self) -> bool: ...
    @property
    def is_input(self) -> bool: ...
    @property
    def is_output(self) -> bool: ...
    @property
    def is_physical(self) -> bool: ...
    @property
    def can_monitor(self) -> bool: ...
    @property
    def is_terminal(self) -> bool: ...
    def request_monitor(self, onoff: bool) -> None: ...

class MidiPort(Port):
    @property
    def is_audio(self) -> Literal[False]: ...
    @property
    def is_midi(self) -> Literal[True]: ...

class OwnPort(Port):
    @property
    def number_of_connections(self) -> int: ...
    @property
    def connections(self) -> list[Port]: ...
    def is_connected_to(self, port: str | Port) -> bool: ...
    def connect(self, port: str | Port) -> None: ...
    def disconnect(self, other: str | Port | None = None) -> None: ...
    def unregister(self) -> None: ...
    def get_buffer(self) -> _CBufferType: ...
    def get_array(self) -> NDArray[numpy.float32]: ...

class OwnMidiPort(MidiPort, OwnPort):
    def __init__(self, port_ptr: _CDataBase, client: Client) -> None: ...
    # The implementation raises NotImplementedError, but this is not an abstract class.
    # `get_buffer()` and `get_array()` are disabled for OwnMidiPort
    def get_buffer(self) -> NoReturn: ...
    def get_array(self) -> NoReturn: ...
    @property
    def max_event_size(self) -> int: ...
    @property
    def lost_midi_events(self) -> int: ...
    def incoming_midi_events(self) -> Generator[tuple[int, _CBufferType], None, None]: ...
    def clear_buffer(self) -> None: ...
    def write_midi_event(self, time: int, event: bytes | Sequence[int] | _CBufferType) -> None: ...
    def reserve_midi_event(self, time: int, size: int) -> _CBufferType: ...

class Ports:
    def __init__(self, client: Client, porttype: str, flag: int) -> None: ...
    def __len__(self) -> int: ...
    def __getitem__(self, name: str) -> Port: ...
    def __iter__(self) -> Iterator[Port]: ...
    def register(self, shortname: str, is_terminal: bool = False, is_physical: bool = False) -> Port: ...
    def clear(self) -> None: ...

class RingBuffer:
    def __init__(self, size: int) -> None: ...
    @property
    def write_space(self) -> int: ...
    def write(self, data: bytes | Iterable[int] | _CBufferType) -> int: ...
    @property
    def write_buffers(self) -> tuple[_CBufferType, _CBufferType]: ...
    def write_advance(self, size: int) -> None: ...
    @property
    def read_space(self) -> int: ...
    def read(self, size: int) -> _CBufferType: ...
    def peek(self, size: int) -> _CBufferType: ...
    @property
    def read_buffers(self) -> tuple[_CBufferType, _CBufferType]: ...
    def read_advance(self, size: int) -> None: ...
    def mlock(self) -> None: ...
    def reset(self, size: int | None = None) -> None: ...
    @property
    def size(self) -> int: ...

class Status:
    def __init__(self, code: int) -> None: ...
    @property
    def failure(self) -> bool: ...
    @property
    def invalid_option(self) -> bool: ...
    @property
    def name_not_unique(self) -> bool: ...
    @property
    def server_started(self) -> bool: ...
    @property
    def server_failed(self) -> bool: ...
    @property
    def server_error(self) -> bool: ...
    @property
    def no_such_client(self) -> bool: ...
    @property
    def load_failure(self) -> bool: ...
    @property
    def init_failure(self) -> bool: ...
    @property
    def shm_failure(self) -> bool: ...
    @property
    def version_error(self) -> bool: ...
    @property
    def backend_error(self) -> bool: ...
    @property
    def client_zombie(self) -> bool: ...

class TransportState:
    def __init__(self, code: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...

class CallbackExit(Exception): ...

def get_property(subject: int | str, key: str) -> tuple[bytes, str] | None: ...
def get_properties(subject: int | str) -> dict[str, tuple[bytes, str]]: ...
def get_all_properties() -> dict[str, dict[str, tuple[bytes, str]]]: ...
def position2dict(pos: _JackPositionT) -> dict[str, Any]: ...  # Anyof[int, float, _CDataBase]
def version() -> tuple[int, int, int, int]: ...
def version_string() -> str: ...
def client_name_size() -> int: ...
def port_name_size() -> int: ...
def set_error_function(callback: Callable[[str], object] | None = None) -> None: ...
def set_info_function(callback: Callable[[str], object] | None = None) -> None: ...
def client_pid(name: str) -> int: ...

METADATA_CONNECTED: str
METADATA_HARDWARE: str
METADATA_ICON_LARGE: str
METADATA_ICON_SMALL: str
METADATA_PORT_GROUP: str
METADATA_PRETTY_NAME: str
if sys.platform != "linux":
    METADATA_EVENT_TYPES: str
    METADATA_ICON_NAME: str
    METADATA_ORDER: str
    METADATA_SIGNAL_TYPE: str



from .australia import (
    Australia as Australia,
    AustralianCapitalTerritory as AustralianCapitalTerritory,
    Hobart as Hobart,
    NewSouthWales as NewSouthWales,
    NorthernTerritory as NorthernTerritory,
    Queensland as Queensland,
    SouthAustralia as SouthAustralia,
    Tasmania as Tasmania,
    Victoria as Victoria,
    WesternAustralia as WesternAustralia,
)
from .marshall_islands import MarshallIslands as MarshallIslands
from .new_zealand import NewZealand as NewZealand



from collections.abc import Iterator
from typing import Literal, TypedDict
from typing_extensions import TypeAlias

from _cffi_backend import _CDataBase

from ._pygit2 import Oid
from .callbacks import RemoteCallbacks
from .enums import FetchPrune
from .refspec import Refspec
from .repository import BaseRepository
from .utils import _IntoStrArray

class TransferProgress:
    total_objects: int
    indexed_objects: int
    received_objects: int
    local_objects: int
    total_deltas: int
    indexed_deltas: int
    received_bytes: int
    def __init__(self, tp: _CDataBase) -> None: ...

_ProxySpec: TypeAlias = Literal[True] | str | None

class _LsRemotesResultEntry(TypedDict):
    local: bool
    loid: Oid | None
    name: str | None
    symref_target: str | None
    oid: Oid

class Remote:
    def __init__(self, repo: BaseRepository, ptr: _CDataBase) -> None: ...
    def __del__(self) -> None: ...
    @property
    def name(self) -> str | None: ...
    @property
    def url(self) -> str | None: ...
    @property
    def push_url(self) -> str | None: ...
    def connect(self, callbacks: RemoteCallbacks | None = None, direction: int = 0, proxy: _ProxySpec = None) -> None: ...
    def fetch(
        self,
        refspecs: _IntoStrArray = None,
        message: bytes | str | None = None,
        callbacks: RemoteCallbacks | None = None,
        prune: FetchPrune = ...,
        proxy: _ProxySpec = None,
        depth: int = 0,
    ) -> TransferProgress: ...
    def ls_remotes(self, callbacks: RemoteCallbacks | None = None, proxy: _ProxySpec = None) -> list[_LsRemotesResultEntry]: ...
    def prune(self, callbacks: RemoteCallbacks | None = None) -> None: ...
    @property
    def refspec_count(self) -> int: ...
    def get_refspec(self, n: int) -> Refspec: ...
    @property
    def fetch_refspecs(self) -> list[str]: ...
    @property
    def push_refspecs(self) -> list[str]: ...
    def push(self, specs: _IntoStrArray, callbacks: RemoteCallbacks | None = None, proxy: _ProxySpec = None) -> None: ...

_RemoteName: TypeAlias = bytes | str

class RemoteCollection:
    def __init__(self, repo: BaseRepository) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[Remote]: ...
    def __getitem__(self, name: int | _RemoteName) -> Remote: ...
    def names(self) -> Iterator[str | None]: ...
    def create(self, name: _RemoteName, url: bytes | str, fetch: bytes | str | None = None) -> Remote: ...
    def create_anonymous(self, url: bytes | str) -> Remote: ...
    def rename(self, name: _RemoteName, new_name: bytes | str) -> list[str]: ...
    def delete(self, name: _RemoteName) -> None: ...
    def set_url(self, name: _RemoteName, url: bytes | str) -> None: ...
    def set_push_url(self, name: _RemoteName, url: bytes | str) -> None: ...
    def add_fetch(self, name: _RemoteName, refspec: bytes | str) -> None: ...
    def add_push(self, name: _RemoteName, refspec: bytes | str) -> None: ...



from collections.abc import Callable

from ._pygit2 import FilterSource

class Filter:
    attributes: str
    @classmethod
    def nattrs(cls) -> int: ...
    def check(self, src: FilterSource, attr_values: list[str | None]) -> None: ...
    def write(self, data: bytes, src: FilterSource, write_next: Callable[[bytes], None]) -> None: ...
    def close(self, write_next: Callable[[bytes], None]) -> None: ...



from typing import overload

from stripe.api_resources.abstract import (
    CreateableAPIResource as CreateableAPIResource,
    ListableAPIResource as ListableAPIResource,
    nested_resource_class_methods as nested_resource_class_methods,
)

class Session(CreateableAPIResource, ListableAPIResource):
    OBJECT_NAME: str
    @overload
    @classmethod
    def expire(cls, session, api_key=None, stripe_version=None, stripe_account=None, **params): ...
    @overload
    @classmethod
    def expire(cls, idempotency_key: str | None = None, **params): ...



import tkinter
from tkinter import ttk

from ._widget import ThemedWidget

class ThemedStyle(ttk.Style, ThemedWidget):
    def __init__(
        self, master: tkinter.Misc | None = ..., *, theme: str | None = ..., gif_override: bool | None = ..., **kwargs
    ) -> None: ...
    # theme_use() can't return None (differs from ttk.Style)
    def theme_use(self, theme_name: str | None = None) -> str: ...  # type: ignore[override]
    def theme_names(self) -> list[str]: ...  # type: ignore[override]



from . import backoff, client, connection, credentials, exceptions, sentinel, utils
from .cluster import RedisCluster as RedisCluster

__all__ = [
    "AuthenticationError",
    "AuthenticationWrongNumberOfArgsError",
    "BlockingConnectionPool",
    "BusyLoadingError",
    "ChildDeadlockedError",
    "Connection",
    "ConnectionError",
    "ConnectionPool",
    "CredentialProvider",
    "DataError",
    "from_url",
    "default_backoff",
    "InvalidResponse",
    "PubSubError",
    "ReadOnlyError",
    "Redis",
    "RedisCluster",
    "RedisError",
    "ResponseError",
    "Sentinel",
    "SentinelConnectionPool",
    "SentinelManagedConnection",
    "SentinelManagedSSLConnection",
    "SSLConnection",
    "UsernamePasswordCredentialProvider",
    "StrictRedis",
    "TimeoutError",
    "UnixDomainSocketConnection",
    "WatchError",
]

default_backoff = backoff.default_backoff

Redis = client.Redis

BlockingConnectionPool = connection.BlockingConnectionPool
Connection = connection.Connection
ConnectionPool = connection.ConnectionPool
SSLConnection = connection.SSLConnection
StrictRedis = client.StrictRedis
UnixDomainSocketConnection = connection.UnixDomainSocketConnection

from_url = utils.from_url

Sentinel = sentinel.Sentinel
SentinelConnectionPool = sentinel.SentinelConnectionPool
SentinelManagedConnection = sentinel.SentinelManagedConnection
SentinelManagedSSLConnection = sentinel.SentinelManagedSSLConnection

AuthenticationError = exceptions.AuthenticationError
AuthenticationWrongNumberOfArgsError = exceptions.AuthenticationWrongNumberOfArgsError
BusyLoadingError = exceptions.BusyLoadingError
ChildDeadlockedError = exceptions.ChildDeadlockedError
ConnectionError = exceptions.ConnectionError
DataError = exceptions.DataError
InvalidResponse = exceptions.InvalidResponse
PubSubError = exceptions.PubSubError
ReadOnlyError = exceptions.ReadOnlyError
RedisError = exceptions.RedisError
ResponseError = exceptions.ResponseError
TimeoutError = exceptions.TimeoutError
WatchError = exceptions.WatchError

CredentialProvider = credentials.CredentialProvider
UsernamePasswordCredentialProvider = credentials.UsernamePasswordCredentialProvider

__version__: str
VERSION: tuple[int | str, ...]



from _typeshed import Incomplete

from hvac.api.system_backend.system_backend_mixin import SystemBackendMixin

class Mount(SystemBackendMixin):
    def list_mounted_secrets_engines(self): ...
    def retrieve_mount_option(self, mount_point, option_name, default_value: Incomplete | None = None): ...
    def enable_secrets_engine(
        self,
        backend_type,
        path: Incomplete | None = None,
        description: Incomplete | None = None,
        config: Incomplete | None = None,
        plugin_name: Incomplete | None = None,
        options: Incomplete | None = None,
        local: bool = False,
        seal_wrap: bool = False,
        **kwargs,
    ): ...
    def disable_secrets_engine(self, path): ...
    def read_mount_configuration(self, path): ...
    def tune_mount_configuration(
        self,
        path,
        default_lease_ttl: Incomplete | None = None,
        max_lease_ttl: Incomplete | None = None,
        description: Incomplete | None = None,
        audit_non_hmac_request_keys: Incomplete | None = None,
        audit_non_hmac_response_keys: Incomplete | None = None,
        listing_visibility: Incomplete | None = None,
        passthrough_request_headers: Incomplete | None = None,
        options: Incomplete | None = None,
        force_no_cache: Incomplete | None = None,
        **kwargs,
    ): ...
    def move_backend(self, from_path, to_path): ...



from _typeshed import Incomplete

from influxdb_client.domain.notification_endpoint_discriminator import NotificationEndpointDiscriminator

class HTTPNotificationEndpoint(NotificationEndpointDiscriminator):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        url: Incomplete | None = None,
        username: Incomplete | None = None,
        password: Incomplete | None = None,
        token: Incomplete | None = None,
        method: Incomplete | None = None,
        auth_method: Incomplete | None = None,
        content_template: Incomplete | None = None,
        headers: Incomplete | None = None,
        id: Incomplete | None = None,
        org_id: Incomplete | None = None,
        user_id: Incomplete | None = None,
        created_at: Incomplete | None = None,
        updated_at: Incomplete | None = None,
        description: Incomplete | None = None,
        name: Incomplete | None = None,
        status: str = "active",
        labels: Incomplete | None = None,
        links: Incomplete | None = None,
        type: str = "http",
    ) -> None: ...
    @property
    def url(self): ...
    @url.setter
    def url(self, url) -> None: ...
    @property
    def username(self): ...
    @username.setter
    def username(self, username) -> None: ...
    @property
    def password(self): ...
    @password.setter
    def password(self, password) -> None: ...
    @property
    def token(self): ...
    @token.setter
    def token(self, token) -> None: ...
    @property
    def method(self): ...
    @method.setter
    def method(self, method) -> None: ...
    @property
    def auth_method(self): ...
    @auth_method.setter
    def auth_method(self, auth_method) -> None: ...
    @property
    def content_template(self): ...
    @content_template.setter
    def content_template(self, content_template) -> None: ...
    @property
    def headers(self): ...
    @headers.setter
    def headers(self, headers) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def uniform_random_intersection_graph(n, m, p, seed: Incomplete | None = None): ...
@_dispatch
def k_random_intersection_graph(n, m, k, seed: Incomplete | None = None): ...
@_dispatch
def general_random_intersection_graph(n, m, p, seed: Incomplete | None = None): ...



from socket import *

from gevent._hub_primitives import (
    wait_on_watcher,
    wait_read as wait_read,
    wait_readwrite as wait_readwrite,
    wait_write as wait_write,
)
from gevent._types import _Watcher

# This matches the stdlib socket module almost exactly, but contains a couple of extensions
# as a result we just pretend we import everything from socket, which is not entirely correct
# but it gets us most of the way there without having to write a really long list of imports
# with the same platform and version checks, just so we can properly distinguish this module's
# socket class from the native socket class (which could cause issues anyways, since functions
# that accept a socket should still accept the gevent implementation...)
# we can put in the work and do it properly once we have a use-case for it.
# the majority of the gevent implementation can be found in _socket3 and _socketcommon
# which also just imports a lot of symbols from the stdlib socket/_socket module

wait = wait_on_watcher

def cancel_wait(watcher: _Watcher, error: type[BaseException] | BaseException) -> None: ...



from _typeshed import Incomplete, SupportsItems
from collections.abc import AsyncGenerator

from influxdb_client.client._base import _BaseQueryApi
from influxdb_client.client.flux_table import FluxRecord, TableList
from influxdb_client.domain.dialect import Dialect
from influxdb_client.domain.organization import Organization

class QueryApiAsync(_BaseQueryApi):
    def __init__(self, influxdb_client, query_options=...) -> None: ...
    async def query(
        self, query: str, org: Incomplete | None = None, params: SupportsItems[str, Incomplete] | None = None
    ) -> TableList: ...
    async def query_stream(
        self, query: str, org: Incomplete | None = None, params: SupportsItems[str, Incomplete] | None = None
    ) -> AsyncGenerator[FluxRecord, None]: ...
    async def query_data_frame(
        self,
        query: str,
        org: str | Organization | None = None,
        data_frame_index: list[str] | None = None,
        params: SupportsItems[str, Incomplete] | None = None,
        use_extension_dtypes: bool = False,
    ): ...
    async def query_data_frame_stream(
        self,
        query: str,
        org: str | Organization | None = None,
        data_frame_index: list[str] | None = None,
        params: SupportsItems[str, Incomplete] | None = None,
        use_extension_dtypes: bool = False,
    ): ...
    async def query_raw(
        self,
        query: str,
        org: str | Organization | None = None,
        dialect: Dialect = ...,
        params: SupportsItems[str, Incomplete] | None = None,
    ) -> str: ...



from collections.abc import Callable, Sequence
from typing import Any, TypeVar

from gevent.events import IPeriodicMonitorThread, MemoryUsageThresholdExceeded, MemoryUsageUnderThreshold
from gevent.hub import Hub
from greenlet import greenlet

__all__ = ["PeriodicMonitoringThread"]

_T = TypeVar("_T")

# FIXME: While it would be nice to import Interface from zope.interface here so the
#        mypy plugin will work correctly for the people that use it, it causes all
#        sorts of issues to reference a module that is not stubbed in typeshed, so
#        for now we punt and just define an alias for Interface and implementer we
#        can get rid of later
def implementer(interface: Any, /) -> Callable[[_T], _T]: ...

class MonitorWarning(RuntimeWarning): ...

class _MonitorEntry:
    function: Callable[[Hub], object]
    period: float
    last_run_time: float
    def __init__(self, function: Callable[[Hub], object], period: float) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...

@implementer(IPeriodicMonitorThread)
class PeriodicMonitoringThread:
    inactive_sleep_time: float
    min_sleep_time: float
    min_memory_monitor_period: float
    should_run: bool
    monitor_thread_ident: int
    pid: int
    def __init__(self, hub: Hub) -> None: ...
    @property
    def hub(self) -> Hub | None: ...
    def monitoring_functions(self) -> list[_MonitorEntry]: ...
    def add_monitoring_function(self, function: Callable[[Hub], object], period: float) -> None: ...
    def calculate_sleep_time(self) -> float: ...
    def kill(self) -> None: ...
    def __call__(self) -> None: ...
    def monitor_blocking(self, hub: Hub) -> tuple[greenlet, Sequence[str]]: ...
    def ignore_current_greenlet_blocking(self) -> None: ...
    def monitor_current_greenlet_blocking(self) -> None: ...
    def can_monitor_memory_usage(self) -> bool: ...
    def install_monitor_memory_usage(self) -> None: ...
    def monitor_memory_usage(self, _hub: Hub) -> MemoryUsageThresholdExceeded | MemoryUsageUnderThreshold | None: ...



from _typeshed import Incomplete
from typing import Any

algorithms_table: Any
salted_table: Any

def hashed(algorithm, value, salt: Incomplete | None = None, raw: bool = False, encoding: str = "utf-8"): ...



from _typeshed import Incomplete
from logging import Logger
from traceback import StackSummary
from typing import Any

log: Logger
ORIGIN_TRACE_HEADER_ATTR_KEY: str

class Entity:
    id: Any
    name: Any
    start_time: Any
    parent_id: Any
    sampled: bool
    in_progress: bool
    http: Any
    annotations: Any
    metadata: Any
    aws: Any
    cause: Any
    subsegments: Any
    end_time: Any
    def __init__(self, name, entity_id: Incomplete | None = None) -> None: ...
    def close(self, end_time: Incomplete | None = None) -> None: ...
    def add_subsegment(self, subsegment) -> None: ...
    def remove_subsegment(self, subsegment) -> None: ...
    def put_http_meta(self, key, value) -> None: ...
    def put_annotation(self, key, value) -> None: ...
    def put_metadata(self, key, value, namespace: str = "default") -> None: ...
    def set_aws(self, aws_meta) -> None: ...
    throttle: bool
    def add_throttle_flag(self) -> None: ...
    fault: bool
    def add_fault_flag(self) -> None: ...
    error: bool
    def add_error_flag(self) -> None: ...
    def apply_status_code(self, status_code) -> None: ...
    def add_exception(self, exception: Exception, stack: StackSummary, remote: bool = False) -> None: ...
    def save_origin_trace_header(self, trace_header) -> None: ...
    def get_origin_trace_header(self): ...
    def serialize(self): ...
    def to_dict(self): ...



from typing import ClassVar

import passlib.utils.handlers as uh

__all__: list[str] = []

class oracle10(uh.HasUserContext, uh.StaticHandler):
    name: ClassVar[str]
    checksum_chars: ClassVar[str]
    checksum_size: ClassVar[int]

class oracle11(uh.HasSalt, uh.GenericHandler):
    name: ClassVar[str]
    checksum_size: ClassVar[int]
    checksum_chars: ClassVar[str]
    min_salt_size: ClassVar[int]
    max_salt_size: ClassVar[int]
    salt_chars: ClassVar[str]
    @classmethod
    def from_string(cls, hash): ...



from _typeshed import Incomplete
from collections.abc import Hashable, Iterable, Mapping, Sequence
from typing import Literal
from typing_extensions import Self, TypeAlias

import numpy as np
from matplotlib.axes import Axes
from matplotlib.colors import Colormap, ListedColormap
from matplotlib.gridspec import GridSpec
from matplotlib.typing import ColorType
from numpy._typing import _ArrayLike, _ArrayLikeInt_co
from numpy.typing import ArrayLike, NDArray
from pandas import DataFrame, Index, Series

from .axisgrid import Grid

# pandas._typing.ListLikeU is partially Unknown
_ListLikeU: TypeAlias = Sequence[Incomplete] | np.ndarray[Incomplete, Incomplete] | Series[Incomplete] | Index[Incomplete]

__all__ = ["heatmap", "clustermap"]

def heatmap(
    data: DataFrame | _ArrayLike[Incomplete],
    *,
    vmin: float | None = None,
    vmax: float | None = None,
    cmap: str | list[ColorType] | Colormap | None = None,
    center: float | None = None,
    robust: bool = False,
    annot: bool | ArrayLike | None = None,
    fmt: str = ".2g",
    annot_kws: dict[str, Incomplete] | None = None,
    linewidths: float = 0,
    linecolor: ColorType = "white",
    cbar: bool = True,
    cbar_kws: dict[str, Incomplete] | None = None,
    cbar_ax: Axes | None = None,
    square: bool = False,
    xticklabels: Literal["auto"] | bool | int | Sequence[str] = "auto",
    yticklabels: Literal["auto"] | bool | int | Sequence[str] = "auto",
    mask: NDArray[np.bool_] | DataFrame | None = None,
    ax: Axes | None = None,
    **kwargs: Incomplete,
) -> Axes: ...

class _DendrogramPlotter:
    axis: int
    array: NDArray[Incomplete]
    data: DataFrame
    shape: tuple[int, int]
    metric: str
    method: str
    label: bool
    rotate: bool
    linkage: NDArray[Incomplete]
    dendrogram: dict[str, list[Incomplete]]
    xticks: list[float] | NDArray[Incomplete]
    yticks: list[float] | NDArray[Incomplete]
    xticklabels: list[str]
    yticklabels: list[str]
    ylabel: str
    xlabel: str
    dependent_coord: list[list[float]]
    independent_coord: list[list[float]]
    def __init__(
        self, data: DataFrame, linkage: NDArray[Incomplete] | None, metric: str, method: str, axis: int, label: bool, rotate: bool
    ) -> None: ...
    @property
    def calculated_linkage(self) -> NDArray[Incomplete]: ...
    def calculate_dendrogram(self) -> dict[str, list[Incomplete]]: ...
    @property
    def reordered_ind(self) -> list[int]: ...
    def plot(self, ax: Axes, tree_kws: dict[str, Incomplete]) -> Self: ...

def dendrogram(
    data: DataFrame,
    *,
    linkage: NDArray[Incomplete] | None = None,
    axis: int = 1,
    label: bool = True,
    metric: str = "euclidean",
    method: str = "average",
    rotate: bool = False,
    tree_kws: dict[str, Incomplete] | None = None,
    ax: Axes | None = None,
) -> _DendrogramPlotter: ...

class ClusterGrid(Grid):
    data: DataFrame
    data2d: DataFrame
    mask: DataFrame
    row_colors: Incomplete
    row_color_labels: Incomplete
    col_colors: Incomplete
    col_color_labels: Incomplete
    gs: GridSpec
    ax_row_dendrogram: Axes
    ax_col_dendrogram: Axes
    ax_row_colors: Axes | None
    ax_col_colors: Axes | None
    ax_heatmap: Axes
    ax_cbar: Axes | None
    cax: Axes | None
    cbar_pos: Incomplete
    dendrogram_row: _DendrogramPlotter | None
    dendrogram_col: _DendrogramPlotter | None
    def __init__(
        self,
        data: (
            _ListLikeU
            | DataFrame
            | dict[Incomplete, Incomplete]
            | Iterable[_ListLikeU | tuple[Hashable, _ListLikeU] | dict[Incomplete, Incomplete]]
            | None
        ),
        pivot_kws: Mapping[str, Incomplete] | None = None,
        z_score: int | None = None,
        standard_scale: int | None = None,
        figsize: tuple[float, float] | None = None,
        row_colors: Incomplete | None = None,
        col_colors: Incomplete | None = None,
        mask: NDArray[np.bool_] | DataFrame | None = None,
        dendrogram_ratio: float | tuple[float, float] | None = None,
        colors_ratio: float | tuple[float, float] | None = None,
        cbar_pos: tuple[float, float, float, float] | None = None,
    ) -> None: ...
    def format_data(
        self,
        data: DataFrame,
        pivot_kws: Mapping[str, Incomplete] | None,
        z_score: int | None = None,
        standard_scale: int | None = None,
    ) -> DataFrame: ...
    @staticmethod
    def z_score(data2d: DataFrame, axis: int = 1) -> DataFrame: ...
    @staticmethod
    def standard_scale(data2d: DataFrame, axis: int = 1) -> DataFrame: ...
    def dim_ratios(self, colors: Incomplete | None, dendrogram_ratio: float, colors_ratio: float) -> list[float]: ...
    @staticmethod
    def color_list_to_matrix_and_cmap(
        colors: Sequence[ColorType], ind: _ArrayLikeInt_co, axis: int = 0
    ) -> tuple[NDArray[np.int_], ListedColormap]: ...
    def plot_dendrograms(
        self,
        row_cluster: bool,
        col_cluster: bool,
        metric: str,
        method: str,
        row_linkage: NDArray[Incomplete] | None,
        col_linkage: NDArray[Incomplete] | None,
        tree_kws: dict[str, Incomplete] | None,
    ) -> None: ...
    def plot_colors(self, xind: _ArrayLikeInt_co, yind: _ArrayLikeInt_co, **kws: Incomplete) -> None: ...
    def plot_matrix(
        self, colorbar_kws: dict[str, Incomplete], xind: _ArrayLikeInt_co, yind: _ArrayLikeInt_co, **kws: Incomplete
    ) -> None: ...
    def plot(
        self,
        metric: str,
        method: str,
        colorbar_kws: dict[str, Incomplete] | None,
        row_cluster: bool,
        col_cluster: bool,
        row_linkage: NDArray[Incomplete] | None,
        col_linkage: NDArray[Incomplete] | None,
        tree_kws: dict[str, Incomplete] | None,
        **kws: Incomplete,
    ) -> Self: ...

def clustermap(
    data: (
        _ListLikeU
        | DataFrame
        | dict[Incomplete, Incomplete]
        | Iterable[_ListLikeU | tuple[Hashable, _ListLikeU] | dict[Incomplete, Incomplete]]
        | None
    ),
    *,
    pivot_kws: dict[str, Incomplete] | None = None,
    method: str = "average",
    metric: str = "euclidean",
    z_score: int | None = None,
    standard_scale: int | None = None,
    figsize: tuple[float, float] | None = (10, 10),
    cbar_kws: dict[str, Incomplete] | None = None,
    row_cluster: bool = True,
    col_cluster: bool = True,
    row_linkage: NDArray[Incomplete] | None = None,
    col_linkage: NDArray[Incomplete] | None = None,
    row_colors: Incomplete | None = None,
    col_colors: Incomplete | None = None,
    mask: NDArray[np.bool_] | DataFrame | None = None,
    dendrogram_ratio: float | tuple[float, float] = 0.2,
    colors_ratio: float | tuple[float, float] = 0.03,
    cbar_pos: tuple[float, float, float, float] | None = (0.02, 0.8, 0.05, 0.18),
    tree_kws: dict[str, Incomplete] | None = None,
    **kwargs: Incomplete,
) -> ClusterGrid: ...



from _typeshed import Incomplete
from typing import ClassVar

from .core import UnitedStates

class Hawaii(UnitedStates):
    include_good_friday: ClassVar[bool]
    include_columbus_day: ClassVar[bool]
    include_election_day_even: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete
    def get_statehood_day(self, year): ...
    def get_variable_days(self, year): ...



from _typeshed import Incomplete

class TemplateSummarySummaryTagRules:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, key: Incomplete | None = None, value: Incomplete | None = None, operator: Incomplete | None = None
    ) -> None: ...
    @property
    def key(self): ...
    @key.setter
    def key(self, key) -> None: ...
    @property
    def value(self): ...
    @value.setter
    def value(self, value) -> None: ...
    @property
    def operator(self): ...
    @operator.setter
    def operator(self, operator) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from networkx.utils.backends import _dispatch

@_dispatch
def min_cost_flow_cost(G, demand: str = "demand", capacity: str = "capacity", weight: str = "weight"): ...
@_dispatch
def min_cost_flow(G, demand: str = "demand", capacity: str = "capacity", weight: str = "weight"): ...
@_dispatch
def cost_of_flow(G, flowDict, weight: str = "weight"): ...
@_dispatch
def max_flow_min_cost(G, s, t, capacity: str = "capacity", weight: str = "weight"): ...



from collections.abc import Callable, Sequence
from contextlib import AbstractContextManager
from stat import S_IMODE as S_IMODE
from types import TracebackType
from typing import IO, Literal
from typing_extensions import Self, TypeAlias

import paramiko
from paramiko import AuthenticationException as AuthenticationException
from pysftp.exceptions import (
    ConnectionException as ConnectionException,
    CredentialException as CredentialException,
    HostKeysException as HostKeysException,
)
from pysftp.helpers import (
    WTCallbacks as WTCallbacks,
    _PathCallback,
    cd as cd,
    known_hosts as known_hosts,
    path_advance as path_advance,
    path_retreat as path_retreat,
    reparent as reparent,
    st_mode_to_int as st_mode_to_int,
    walktree as walktree,
)

class CnOpts:
    log: bool
    compression: bool
    ciphers: Sequence[str] | None
    hostkeys: paramiko.HostKeys | None
    def __init__(self, knownhosts: str | None = None) -> None: ...
    def get_hostkey(self, host: str) -> paramiko.PKey: ...

_Callback: TypeAlias = Callable[[int, int], object]
_Path: TypeAlias = str | bytes

class Connection:
    def __init__(
        self,
        host: str,
        username: str | None = None,
        private_key: str | paramiko.RSAKey | paramiko.AgentKey | None = None,
        password: str | None = None,
        port: int = 22,
        private_key_pass: str | None = None,
        ciphers: Sequence[str] | None = None,
        log: bool = False,
        cnopts: CnOpts | None = None,
        default_path: _Path | None = None,
    ) -> None: ...
    @property
    def pwd(self) -> str: ...
    def get(
        self, remotepath: _Path, localpath: _Path | None = None, callback: _Callback | None = None, preserve_mtime: bool = False
    ) -> None: ...
    def get_d(self, remotedir: _Path, localdir: _Path, preserve_mtime: bool = False) -> None: ...
    def get_r(self, remotedir: _Path, localdir: _Path, preserve_mtime: bool = False) -> None: ...
    def getfo(self, remotepath: _Path, flo: IO[bytes], callback: _Callback | None = None) -> int: ...
    def put(
        self,
        localpath: _Path,
        remotepath: _Path | None = None,
        callback: _Callback | None = None,
        confirm: bool = True,
        preserve_mtime: bool = False,
    ) -> paramiko.SFTPAttributes: ...
    def put_d(self, localpath: _Path, remotepath: _Path, confirm: bool = True, preserve_mtime: bool = False) -> None: ...
    def put_r(self, localpath: _Path, remotepath: _Path, confirm: bool = True, preserve_mtime: bool = False) -> None: ...
    def putfo(
        self,
        flo: IO[bytes],
        remotepath: _Path | None = None,
        file_size: int = 0,
        callback: _Callback | None = None,
        confirm: bool = True,
    ) -> paramiko.SFTPAttributes: ...
    def execute(self, command: str) -> list[str]: ...
    def cd(self, remotepath: _Path | None = None) -> AbstractContextManager[None]: ...  # noqa: F811
    def chdir(self, remotepath: _Path) -> None: ...
    def cwd(self, remotepath: _Path) -> None: ...
    def chmod(self, remotepath: _Path, mode: int = 777) -> None: ...
    def chown(self, remotepath: _Path, uid: int | None = None, gid: int | None = None) -> None: ...
    def getcwd(self) -> str: ...
    def listdir(self, remotepath: _Path = ".") -> list[str]: ...
    def listdir_attr(self, remotepath: _Path = ".") -> list[paramiko.SFTPAttributes]: ...
    def mkdir(self, remotepath: _Path, mode: int = 777) -> None: ...
    def normalize(self, remotepath: _Path) -> str: ...
    def isdir(self, remotepath: _Path) -> bool: ...
    def isfile(self, remotepath: _Path) -> bool: ...
    def makedirs(self, remotedir: _Path, mode: int = 777) -> None: ...
    def readlink(self, remotelink: _Path) -> str: ...
    def remove(self, remotefile: _Path) -> None: ...
    def unlink(self, remotefile: _Path) -> None: ...
    def rmdir(self, remotepath: _Path) -> None: ...
    def rename(self, remote_src: _Path, remote_dest: _Path) -> None: ...
    def stat(self, remotepath: _Path) -> paramiko.SFTPAttributes: ...
    def lstat(self, remotepath: _Path) -> paramiko.SFTPAttributes: ...
    def close(self) -> None: ...
    def open(self, remote_file: _Path, mode: str = "r", bufsize: int = -1) -> paramiko.SFTPFile: ...
    def exists(self, remotepath: _Path) -> bool: ...
    def lexists(self, remotepath: _Path) -> bool: ...
    def symlink(self, remote_src: _Path, remote_dest: _Path) -> None: ...
    def truncate(self, remotepath: _Path, size: int) -> int: ...
    def walktree(  # noqa: F811
        self,
        remotepath: _Path,
        fcallback: _PathCallback,
        dcallback: _PathCallback,
        ucallback: _PathCallback,
        recurse: bool = True,
    ) -> None: ...
    @property
    def sftp_client(self) -> paramiko.SFTPClient: ...
    @property
    def active_ciphers(self) -> tuple[str, str]: ...
    @property
    def active_compression(self) -> tuple[str, str]: ...
    @property
    def security_options(self) -> paramiko.SecurityOptions: ...
    @property
    def logfile(self) -> str | Literal[False]: ...
    @property
    def timeout(self) -> float | None: ...
    @timeout.setter
    def timeout(self, val: float | None) -> None: ...
    @property
    def remote_server_key(self) -> paramiko.PKey: ...
    def __del__(self) -> None: ...
    def __enter__(self) -> Self: ...
    def __exit__(
        self, etype: type[BaseException] | None, value: BaseException | None, traceback: TracebackType | None
    ) -> None: ...



import ast
from argparse import Namespace
from binascii import Incomplete
from collections.abc import Iterator
from typing import ClassVar
from typing_extensions import TypeAlias

_Error: TypeAlias = tuple[int, int, str, type[BuiltinsChecker]]
_OptionManager: TypeAlias = Incomplete  # flake8.options.manager.OptionManager

class BuiltinsChecker:
    name: ClassVar[str]
    version: ClassVar[str]
    assign_msg: ClassVar[str]
    argument_msg: ClassVar[str]
    class_attribute_msg: ClassVar[str]
    import_msg: ClassVar[str]
    module_name_msg: ClassVar[str]
    lambda_argument_msg: ClassVar[str]

    names: ClassVar[list[str]]
    ignore_list: ClassVar[set[str]]
    ignored_module_names: ClassVar[set[str]]

    def __init__(self, tree: ast.AST, filename: str) -> None: ...
    @classmethod
    def add_options(cls, option_manager: _OptionManager) -> None: ...
    @classmethod
    def parse_options(cls, options: Namespace) -> None: ...
    def run(self) -> Iterator[_Error]: ...
    def check_assignment(self, statement: ast.Assign | ast.AnnAssign | ast.NamedExpr) -> Iterator[_Error]: ...
    def check_function_definition(self, statement: ast.FunctionDef | ast.AsyncFunctionDef) -> Iterator[_Error]: ...
    def check_lambda_definition(self, statement: ast.Lambda) -> Iterator[_Error]: ...
    def check_for_loop(self, statement: ast.For | ast.AsyncFor) -> Iterator[_Error]: ...
    def check_with(self, statement: ast.With | ast.AsyncWith) -> Iterator[_Error]: ...
    def check_exception(self, statement: ast.excepthandler) -> Iterator[_Error]: ...
    def check_comprehension(
        self, statement: ast.ListComp | ast.SetComp | ast.DictComp | ast.GeneratorExp
    ) -> Iterator[_Error]: ...
    def check_import(self, statement: ast.Import | ast.ImportFrom) -> Iterator[_Error]: ...
    def check_class(self, statement: ast.ClassDef) -> Iterator[_Error]: ...
    def error(self, statement: ast.AST | None = None, variable: str | None = None, message: str | None = None) -> _Error: ...
    def check_module_name(self, filename: str) -> Iterator[_Error]: ...



from _typeshed import FileDescriptorOrPath
from typing import Final

from Xlib.X import (
    FamilyChaos as FamilyChaos,
    FamilyDECnet as FamilyDECnet,
    FamilyInternet as FamilyInternet,
    FamilyInternetV6 as FamilyInternetV6,
    FamilyServerInterpreted as FamilyServerInterpreted,
)

FamilyLocal: Final = 256

class Xauthority:
    entries: list[tuple[bytes, bytes, bytes, bytes, bytes]]
    def __init__(self, filename: FileDescriptorOrPath | None = None) -> None: ...
    def __len__(self) -> int: ...
    def __getitem__(self, i: int) -> tuple[bytes, bytes, bytes, bytes, bytes]: ...
    def get_best_auth(
        self, family: bytes, address: bytes, dispno: bytes, types: tuple[bytes, ...] = (b"MIT-MAGIC-COOKIE-1",)
    ) -> tuple[bytes, bytes]: ...



from typing import ClassVar

from .core import UnitedStates

class TexasBase(UnitedStates):
    include_columbus_day: ClassVar[bool]
    texas_include_confederate_heroes: ClassVar[bool]
    texas_include_independance_day: ClassVar[bool]
    texas_san_jacinto_day: ClassVar[bool]
    texas_emancipation_day: ClassVar[bool]
    texas_lyndon_johnson_day: ClassVar[bool]
    include_thanksgiving_friday: ClassVar[bool]
    include_christmas_eve: ClassVar[bool]
    include_boxing_day: ClassVar[bool]
    def get_fixed_holidays(self, year): ...

class Texas(TexasBase):
    texas_include_confederate_heroes: ClassVar[bool]
    texas_include_independance_day: ClassVar[bool]
    texas_san_jacinto_day: ClassVar[bool]
    texas_emancipation_day: ClassVar[bool]
    texas_lyndon_johnson_day: ClassVar[bool]
    include_thanksgiving_friday: ClassVar[bool]
    include_christmas_eve: ClassVar[bool]
    include_boxing_day: ClassVar[bool]



from _typeshed import Incomplete
from typing import Final

from braintree.resource import Resource

class Address(Resource):
    class ShippingMethod:
        SameDay: Final = "same_day"
        NextDay: Final = "next_day"
        Priority: Final = "priority"
        Ground: Final = "ground"
        Electronic: Final = "electronic"
        ShipToStore: Final = "ship_to_store"
        PickupInStore: Final = "pickup_in_store"

    @staticmethod
    def create(params: Incomplete | None = None): ...
    @staticmethod
    def delete(customer_id, address_id): ...
    @staticmethod
    def find(customer_id, address_id): ...
    @staticmethod
    def update(customer_id, address_id, params: Incomplete | None = None): ...
    @staticmethod
    def create_signature(): ...
    @staticmethod
    def update_signature(): ...



from _typeshed import Incomplete

from antlr4.atn.ATN import ATN as ATN
from antlr4.atn.ATNDeserializationOptions import ATNDeserializationOptions as ATNDeserializationOptions
from antlr4.atn.ATNState import *
from antlr4.atn.ATNType import ATNType as ATNType
from antlr4.atn.LexerAction import *
from antlr4.atn.Transition import *
from antlr4.Token import Token as Token

SERIALIZED_VERSION: int

class ATNDeserializer:
    deserializationOptions: Incomplete
    def __init__(self, options: ATNDeserializationOptions | None = None) -> None: ...
    data: Incomplete
    pos: int
    def deserialize(self, data: list[int]): ...
    def checkVersion(self) -> None: ...
    def readATN(self): ...
    def readStates(self, atn: ATN): ...
    def readRules(self, atn: ATN): ...
    def readModes(self, atn: ATN): ...
    def readSets(self, atn: ATN, sets: list[Incomplete]): ...
    def readEdges(self, atn: ATN, sets: list[Incomplete]): ...
    def readDecisions(self, atn: ATN): ...
    def readLexerActions(self, atn: ATN): ...
    def generateRuleBypassTransitions(self, atn: ATN): ...
    def generateRuleBypassTransition(self, atn: ATN, idx: int): ...
    def stateIsEndStateFor(self, state: ATNState, idx: int): ...
    def markPrecedenceDecisions(self, atn: ATN): ...
    def verifyATN(self, atn: ATN): ...
    def checkCondition(self, condition: bool, message: Incomplete | None = None): ...
    def readInt(self): ...
    edgeFactories: Incomplete
    def edgeFactory(self, atn: ATN, type: int, src: int, trg: int, arg1: int, arg2: int, arg3: int, sets: list[Incomplete]): ...
    stateFactories: Incomplete
    def stateFactory(self, type: int, ruleIndex: int): ...
    CHANNEL: int
    CUSTOM: int
    MODE: int
    MORE: int
    POP_MODE: int
    PUSH_MODE: int
    SKIP: int
    TYPE: int
    actionFactories: Incomplete
    def lexerActionFactory(self, type: int, data1: int, data2: int): ...



from _typeshed import Incomplete
from collections.abc import Callable, Hashable
from io import TextIOBase
from typing_extensions import TypeAlias

from networkx.classes.graph import Graph, _Node
from networkx.utils.backends import _dispatch

# from pygraphviz.agraph import AGraph as _AGraph
_AGraph: TypeAlias = Incomplete

@_dispatch
def from_agraph(A, create_using: Incomplete | None = None) -> Graph[Incomplete]: ...
def to_agraph(N: Graph[Hashable]) -> _AGraph: ...
def write_dot(G: Graph[Hashable], path: str | TextIOBase) -> None: ...
@_dispatch
def read_dot(path: str | TextIOBase) -> Graph[Incomplete]: ...
def graphviz_layout(
    G: Graph[_Node], prog: str = "neato", root: str | None = None, args: str = ""
) -> dict[_Node, tuple[float, float]]: ...

pygraphviz_layout = graphviz_layout

def view_pygraphviz(
    G: Graph[_Node],
    # From implementation looks like Callable could return object since it's always immediatly stringified
    # But judging by documentation this seems like an extra runtime safty thing and not intended
    # Leaving as str unless anyone reports a valid use-case
    edgelabel: str | Callable[[_Node], str] | None = None,
    prog: str = "dot",
    args: str = "",
    suffix: str = "",
    path: str | None = None,
    show: bool = True,
): ...



import datetime
from typing import Any
from typing_extensions import Self

ZERO: datetime.timedelta

class FixedOffsetTimezone(datetime.tzinfo):
    def __init__(self, offset: datetime.timedelta | float | None = None, name: str | None = None) -> None: ...
    def __new__(cls, offset: datetime.timedelta | float | None = None, name: str | None = None) -> Self: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __getinitargs__(self) -> tuple[Any, ...]: ...
    def utcoffset(self, dt: datetime.datetime | None) -> datetime.timedelta: ...
    def tzname(self, dt: datetime.datetime | None) -> str: ...
    def dst(self, dt: datetime.datetime | None) -> datetime.timedelta: ...

STDOFFSET: datetime.timedelta
DSTOFFSET: datetime.timedelta
DSTDIFF: datetime.timedelta

class LocalTimezone(datetime.tzinfo):
    def utcoffset(self, dt: datetime.datetime) -> datetime.timedelta: ...  # type: ignore[override]
    def dst(self, dt: datetime.datetime) -> datetime.timedelta: ...  # type: ignore[override]
    def tzname(self, dt: datetime.datetime) -> str: ...  # type: ignore[override]

LOCAL: LocalTimezone



from _typeshed import Incomplete

class Organization:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        links: Incomplete | None = None,
        id: str | None = None,
        name: Incomplete | None = None,
        default_storage_type: str | None = None,
        description: Incomplete | None = None,
        created_at: Incomplete | None = None,
        updated_at: Incomplete | None = None,
        status: str = "active",
    ) -> None: ...
    @property
    def links(self): ...
    @links.setter
    def links(self, links) -> None: ...
    @property
    def id(self) -> str: ...
    @id.setter
    def id(self, id: str) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    default_storage_type: str | None
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def created_at(self): ...
    @created_at.setter
    def created_at(self, created_at) -> None: ...
    @property
    def updated_at(self): ...
    @updated_at.setter
    def updated_at(self, updated_at) -> None: ...
    @property
    def status(self): ...
    @status.setter
    def status(self, status) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from hvac.api.vault_api_base import VaultApiBase

class JWT(VaultApiBase):
    DEFAULT_PATH: str
    def resolve_path(self, path): ...
    def configure(
        self,
        oidc_discovery_url: Incomplete | None = None,
        oidc_discovery_ca_pem: Incomplete | None = None,
        oidc_client_id: Incomplete | None = None,
        oidc_client_secret: Incomplete | None = None,
        oidc_response_mode: Incomplete | None = None,
        oidc_response_types: Incomplete | None = None,
        jwks_url: Incomplete | None = None,
        jwks_ca_pem: Incomplete | None = None,
        jwt_validation_pubkeys: Incomplete | None = None,
        bound_issuer: Incomplete | None = None,
        jwt_supported_algs: Incomplete | None = None,
        default_role: Incomplete | None = None,
        provider_config: Incomplete | None = None,
        path: Incomplete | None = None,
    ): ...
    def read_config(self, path: Incomplete | None = None): ...
    def create_role(
        self,
        name,
        user_claim,
        allowed_redirect_uris,
        role_type: str = "jwt",
        bound_audiences: Incomplete | None = None,
        clock_skew_leeway: Incomplete | None = None,
        expiration_leeway: Incomplete | None = None,
        not_before_leeway: Incomplete | None = None,
        bound_subject: Incomplete | None = None,
        bound_claims: Incomplete | None = None,
        groups_claim: Incomplete | None = None,
        claim_mappings: Incomplete | None = None,
        oidc_scopes: Incomplete | None = None,
        bound_claims_type: str = "string",
        verbose_oidc_logging: bool = False,
        token_ttl: Incomplete | None = None,
        token_max_ttl: Incomplete | None = None,
        token_policies: Incomplete | None = None,
        token_bound_cidrs: Incomplete | None = None,
        token_explicit_max_ttl: Incomplete | None = None,
        token_no_default_policy: Incomplete | None = None,
        token_num_uses: Incomplete | None = None,
        token_period: Incomplete | None = None,
        token_type: Incomplete | None = None,
        path: Incomplete | None = None,
        user_claim_json_pointer: Incomplete | None = None,
    ): ...
    def read_role(self, name, path: Incomplete | None = None): ...
    def list_roles(self, path: Incomplete | None = None): ...
    def delete_role(self, name, path: Incomplete | None = None): ...
    def oidc_authorization_url_request(self, role, redirect_uri, path: Incomplete | None = None): ...
    def oidc_callback(self, state, nonce, code, path: Incomplete | None = None): ...
    def jwt_login(self, role, jwt, use_token: bool = True, path: Incomplete | None = None): ...



from re import Pattern
from xml.etree.ElementTree import Element

from markdown.extensions import Extension
from markdown.treeprocessors import Treeprocessor

ATTR_RE: Pattern[str]

class LegacyAttrs(Treeprocessor):
    def run(self, doc: Element) -> None: ...
    def handleAttributes(self, el: Element, txt: str) -> str: ...

class LegacyAttrExtension(Extension): ...

def makeExtension(**kwargs) -> LegacyAttrExtension: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import IslamicCalendar

class Algeria(IslamicCalendar):
    include_labour_day: ClassVar[bool]
    include_prophet_birthday: ClassVar[bool]
    include_eid_al_fitr: ClassVar[bool]
    include_day_of_sacrifice: ClassVar[bool]
    include_islamic_new_year: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete
    ISLAMIC_HOLIDAYS: Incomplete



from .main import cli_main as cli_main, main as main
from .renderer import render as render
from .tokenizer import ChevronError as ChevronError

__all__ = ["main", "render", "cli_main", "ChevronError"]



def fingerprint128(a: str, /) -> tuple[int, int]: ...
def fingerprint32(a: str, /) -> int: ...
def fingerprint64(a: str, /) -> int: ...
def hash128(a: str, /) -> tuple[int, int]: ...
def hash128withseed(a: str, seed_low: int, seed_high: int, /) -> tuple[int, int]: ...
def hash32(a: str, /) -> int: ...
def hash32withseed(a: str, seed: int, /) -> int: ...
def hash64(a: str, /) -> int: ...
def hash64withseed(a: str, seed: int, /) -> int: ...



from _typeshed import Incomplete

from influxdb_client.domain.view_properties import ViewProperties

class SimpleTableViewProperties(ViewProperties):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: Incomplete | None = None,
        show_all: Incomplete | None = None,
        queries: Incomplete | None = None,
        shape: Incomplete | None = None,
        note: Incomplete | None = None,
        show_note_when_empty: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def show_all(self): ...
    @show_all.setter
    def show_all(self, show_all) -> None: ...
    @property
    def queries(self): ...
    @queries.setter
    def queries(self, queries) -> None: ...
    @property
    def shape(self): ...
    @shape.setter
    def shape(self, shape) -> None: ...
    @property
    def note(self): ...
    @note.setter
    def note(self, note) -> None: ...
    @property
    def show_note_when_empty(self): ...
    @show_note_when_empty.setter
    def show_note_when_empty(self, show_note_when_empty) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from typing import IO, AnyStr, Generic, Literal

class ContainerIO(Generic[AnyStr]):
    fh: IO[AnyStr]
    pos: int
    offset: int
    length: int
    def __init__(self, file: IO[AnyStr], offset: int, length: int) -> None: ...
    def isatty(self) -> bool: ...
    def seek(self, offset: int, mode: Literal[0, 1, 2] = 0) -> None: ...
    def tell(self) -> int: ...
    def read(self, n: int = 0) -> AnyStr: ...
    def readline(self) -> AnyStr: ...
    def readlines(self) -> list[AnyStr]: ...



from abc import ABCMeta, abstractmethod
from collections.abc import Mapping
from typing import Any, Generic, TypeVar
from typing_extensions import Self

from requests import Response, Session

_R = TypeVar("_R")

class Adapter(Generic[_R], metaclass=ABCMeta):
    @classmethod
    def from_adapter(cls, adapter: Adapter[_R]) -> Self: ...
    base_uri: str
    token: str | None
    namespace: str | None
    session: Session
    allow_redirects: bool
    ignore_exceptions: bool
    strict_http: bool
    request_header: bool
    def __init__(
        self,
        base_uri: str = "http://localhost:8200",
        token: str | None = None,
        cert: tuple[str, str] | None = None,
        verify: bool = True,
        timeout: int = 30,
        proxies: Mapping[str, str] | None = None,
        allow_redirects: bool = True,
        session: Session | None = None,
        namespace: str | None = None,
        ignore_exceptions: bool = False,
        strict_http: bool = False,
        request_header: bool = True,
    ) -> None: ...
    @staticmethod
    def urljoin(*args: object) -> str: ...
    def close(self) -> None: ...
    def get(self, url: str, **kwargs: Any) -> _R: ...
    def post(self, url: str, **kwargs: Any) -> _R: ...
    def put(self, url: str, **kwargs: Any) -> _R: ...
    def delete(self, url: str, **kwargs: Any) -> _R: ...
    def list(self, url: str, **kwargs: Any) -> _R: ...
    def head(self, url: str, **kwargs: Any) -> _R: ...
    def login(self, url: str, use_token: bool = True, **kwargs: Any): ...
    @abstractmethod
    def get_login_token(self, response: _R) -> str: ...
    @abstractmethod
    def request(
        self, method, url: str, headers: Mapping[str, str] | None = None, raise_exception: bool = True, **kwargs: Any
    ) -> _R: ...

class _GenericRawAdapter(Adapter[_R]):
    def get_login_token(self, response: _R) -> str: ...
    def request(
        self, method: str, url: str, headers: Mapping[str, str] | None = None, raise_exception: bool = True, **kwargs: Any
    ) -> _R: ...

class RawAdapter(_GenericRawAdapter[Response]): ...

class JSONAdapter(_GenericRawAdapter[Response | dict[Any, Any]]):
    def get_login_token(self, response: Response | dict[Any, Any]) -> str: ...
    def request(self, *args: Any, **kwargs: Any) -> Response | dict[Any, Any]: ...

Request = RawAdapter



from collections.abc import Iterator, Mapping, MutableMapping
from typing_extensions import Self

from paramiko.pkey import PKey

class _SubDict(MutableMapping[str, PKey]):
    # Internal to HostKeys.lookup()
    def __init__(self, hostname: str, entries: list[HostKeyEntry], hostkeys: HostKeys) -> None: ...
    def __iter__(self) -> Iterator[str]: ...
    def __len__(self) -> int: ...
    def __delitem__(self, key: str) -> None: ...
    def __getitem__(self, key: str) -> PKey: ...
    def __setitem__(self, key: str, val: PKey) -> None: ...
    def keys(self) -> list[str]: ...  # type: ignore[override]

class HostKeys(MutableMapping[str, _SubDict]):
    def __init__(self, filename: str | None = None) -> None: ...
    def add(self, hostname: str, keytype: str, key: PKey) -> None: ...
    def load(self, filename: str) -> None: ...
    def save(self, filename: str) -> None: ...
    def lookup(self, hostname: str) -> _SubDict | None: ...
    def check(self, hostname: str, key: PKey) -> bool: ...
    def clear(self) -> None: ...
    def __iter__(self) -> Iterator[str]: ...
    def __len__(self) -> int: ...
    def __getitem__(self, key: str) -> _SubDict: ...
    def __delitem__(self, key: str) -> None: ...
    def __setitem__(self, hostname: str, entry: Mapping[str, PKey]) -> None: ...
    def keys(self) -> list[str]: ...  # type: ignore[override]
    def values(self) -> list[_SubDict]: ...  # type: ignore[override]
    @staticmethod
    def hash_host(hostname: str, salt: str | None = None) -> str: ...

class InvalidHostKey(Exception):
    line: str
    exc: Exception
    def __init__(self, line: str, exc: Exception) -> None: ...

class HostKeyEntry:
    valid: bool
    hostnames: list[str]
    key: PKey
    def __init__(self, hostnames: list[str] | None = None, key: PKey | None = None) -> None: ...
    @classmethod
    def from_line(cls, line: str, lineno: int | None = None) -> Self | None: ...
    def to_line(self) -> str | None: ...



from _typeshed import Incomplete

class JSONCommands:
    def arrappend(self, name: str, path: str | None = ".", *args) -> list[int | None]: ...
    def arrindex(
        self, name: str, path: str, scalar: int, start: int | None = None, stop: int | None = None
    ) -> list[int | None]: ...
    def arrinsert(self, name: str, path: str, index: int, *args) -> list[int | None]: ...
    def arrlen(self, name: str, path: str | None = ".") -> list[int | None]: ...
    def arrpop(self, name: str, path: str | None = ".", index: int | None = -1) -> list[str | None]: ...
    def arrtrim(self, name: str, path: str, start: int, stop: int) -> list[int | None]: ...
    def type(self, name: str, path: str | None = ".") -> list[str]: ...
    def resp(self, name: str, path: str | None = ".") -> list[Incomplete]: ...
    def objkeys(self, name, path="."): ...
    def objlen(self, name, path="."): ...
    def numincrby(self, name, path, number): ...
    def nummultby(self, name, path, number): ...
    def clear(self, name, path="."): ...
    def delete(self, key, path="."): ...
    forget = delete
    def get(self, name, *args, no_escape: bool = False): ...
    def mget(self, keys, path): ...
    def set(self, name, path, obj, nx: bool = False, xx: bool = False, decode_keys: bool = False): ...
    def set_file(self, name, path, file_name, nx: bool = False, xx: bool = False, decode_keys: bool = False): ...
    def set_path(self, json_path, root_folder, nx: bool = False, xx: bool = False, decode_keys: bool = False): ...
    def strlen(self, name, path: Incomplete | None = None): ...
    def toggle(self, name, path="."): ...
    def strappend(self, name, value, path="."): ...
    def debug(self, subcommand, key: Incomplete | None = None, path="."): ...
    def jsonget(self, *args, **kwargs): ...
    def jsonmget(self, *args, **kwargs): ...
    def jsonset(self, *args, **kwargs): ...



STATE_KEY: int
STATE_VALUE: int

def md5_h(value): ...
def md5_kd(k, s): ...
def md5_hex(value): ...
def md5_hmac(k, s): ...
def sasl_digest_md5(connection, controls): ...
def decode_directives(directives_string): ...



from _typeshed import Incomplete

class DocumentUploadGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def create(self, params: Incomplete | None = None): ...



from _typeshed import Incomplete
from collections.abc import Generator

from qrcode.base import RSBlock as RSBlock

MODE_NUMBER: Incomplete
MODE_ALPHA_NUM: Incomplete
MODE_8BIT_BYTE: Incomplete
MODE_KANJI: Incomplete
MODE_SIZE_SMALL: Incomplete
MODE_SIZE_MEDIUM: Incomplete
MODE_SIZE_LARGE: Incomplete
ALPHA_NUM: bytes
RE_ALPHA_NUM: Incomplete
NUMBER_LENGTH: Incomplete
PATTERN_POSITION_TABLE: Incomplete
G15: Incomplete
G18: Incomplete
G15_MASK: Incomplete
PAD0: int
PAD1: int
BIT_LIMIT_TABLE: Incomplete

def BCH_type_info(data): ...
def BCH_type_number(data): ...
def BCH_digit(data): ...
def pattern_position(version): ...
def mask_func(pattern): ...
def mode_sizes_for_version(version): ...
def length_in_bits(mode, version): ...
def check_version(version) -> None: ...
def lost_point(modules): ...
def optimal_data_chunks(data, minimum: int = 4) -> Generator[Incomplete, None, None]: ...
def to_bytestring(data): ...
def optimal_mode(data): ...

class QRData:
    mode: Incomplete
    data: Incomplete
    def __init__(self, data, mode: Incomplete | None = None, check_data: bool = True) -> None: ...
    def __len__(self) -> int: ...
    def write(self, buffer) -> None: ...

class BitBuffer:
    buffer: Incomplete
    length: int
    def __init__(self) -> None: ...
    def get(self, index): ...
    def put(self, num, length) -> None: ...
    def __len__(self) -> int: ...
    def put_bit(self, bit) -> None: ...

def create_bytes(buffer: BitBuffer, rs_blocks: list[RSBlock]): ...
def create_data(version, error_correction, data_list): ...



from _typeshed import Incomplete

class BuilderConfig:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        buckets: Incomplete | None = None,
        tags: Incomplete | None = None,
        functions: Incomplete | None = None,
        aggregate_window: Incomplete | None = None,
    ) -> None: ...
    @property
    def buckets(self): ...
    @buckets.setter
    def buckets(self, buckets) -> None: ...
    @property
    def tags(self): ...
    @tags.setter
    def tags(self, tags) -> None: ...
    @property
    def functions(self): ...
    @functions.setter
    def functions(self, functions) -> None: ...
    @property
    def aggregate_window(self): ...
    @aggregate_window.setter
    def aggregate_window(self, aggregate_window) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from typing_extensions import Self

from stripe.api_resources.abstract.api_resource import APIResource as APIResource

class UpdateableAPIResource(APIResource):
    @classmethod
    def modify(cls, sid: str, **params) -> Self: ...
    def save(self, idempotency_key: str | None = None) -> Self: ...



import re
from _typeshed import SupportsRichComparison
from collections.abc import Callable, Iterator
from typing import Any, Literal, NoReturn

ESCAPE: re.Pattern[str]
ESCAPE_ASCII: re.Pattern[str]
HAS_UTF8: re.Pattern[str]
ESCAPE_DCT: dict[str, str]
FLOAT_REPR: Callable[[object], str]

class JSONEncoder:
    item_separator: str
    key_separator: str
    skipkeys: bool
    ensure_ascii: bool
    check_circular: bool
    allow_nan: bool
    sort_keys: bool
    indent: str
    encoding: str
    use_decimal: bool
    namedtuple_as_object: bool
    tuple_as_array: bool
    bigint_as_string: bool
    item_sort_key: Callable[[Any], SupportsRichComparison] | None
    for_json: bool
    ignore_nan: bool
    int_as_string_bitcount: int | None
    iterable_as_array: bool

    def __init__(
        self,
        skipkeys: bool = ...,
        ensure_ascii: bool = ...,
        check_circular: bool = ...,
        allow_nan: bool = ...,
        sort_keys: bool = ...,
        indent: str | int | None = ...,
        separators: tuple[str, str] | None = ...,
        encoding: str = ...,
        default: Callable[[Any], Any] | None = ...,
        use_decimal: bool = ...,
        namedtuple_as_object: bool = ...,
        tuple_as_array: bool = ...,
        bigint_as_string: bool = ...,
        item_sort_key: Callable[[Any], SupportsRichComparison] | None = ...,
        for_json: bool = ...,
        ignore_nan: bool = ...,
        int_as_string_bitcount: int | None = ...,
        iterable_as_array: bool = ...,
    ) -> None: ...
    def encode(self, o: Any) -> str: ...
    def default(self, o: Any) -> NoReturn: ...
    def iterencode(self, o: Any) -> Iterator[str]: ...

class JSONEncoderForHTML(JSONEncoder): ...

def encode_basestring(s: str | bytes, _PY3: Literal[True] = ..., _q: str = ...) -> str: ...
def encode_basestring_ascii(s: str | bytes, _PY3: Literal[True] = ...) -> str: ...



from _typeshed import Incomplete

from stripe import api_requestor as api_requestor, connect_api_base as connect_api_base, error as error

class OAuth:
    @staticmethod
    def authorize_url(express: bool = False, **params): ...
    @staticmethod
    def token(api_key: Incomplete | None = None, **params): ...
    @staticmethod
    def deauthorize(api_key: Incomplete | None = None, **params): ...



from typing import ClassVar

from .core import UnitedStates

class RhodeIsland(UnitedStates):
    include_federal_presidents_day: ClassVar[bool]
    include_election_day_even: ClassVar[bool]
    def get_variable_days(self, year): ...



from _typeshed import Incomplete

from antlr4.atn.Transition import Transition as Transition

INITIAL_NUM_TRANSITIONS: int

class ATNState:
    INVALID_TYPE: int
    BASIC: int
    RULE_START: int
    BLOCK_START: int
    PLUS_BLOCK_START: int
    STAR_BLOCK_START: int
    TOKEN_START: int
    RULE_STOP: int
    BLOCK_END: int
    STAR_LOOP_BACK: int
    STAR_LOOP_ENTRY: int
    PLUS_LOOP_BACK: int
    LOOP_END: int
    serializationNames: Incomplete
    INVALID_STATE_NUMBER: int
    atn: Incomplete
    stateNumber: Incomplete
    stateType: Incomplete
    ruleIndex: int
    epsilonOnlyTransitions: bool
    transitions: Incomplete
    nextTokenWithinRule: Incomplete
    def __init__(self) -> None: ...
    def __hash__(self): ...
    def __eq__(self, other): ...
    def onlyHasEpsilonTransitions(self): ...
    def isNonGreedyExitState(self): ...
    def addTransition(self, trans: Transition, index: int = -1): ...

class BasicState(ATNState):
    stateType: Incomplete
    def __init__(self) -> None: ...

class DecisionState(ATNState):
    decision: int
    nonGreedy: bool
    def __init__(self) -> None: ...

class BlockStartState(DecisionState):
    endState: Incomplete
    def __init__(self) -> None: ...

class BasicBlockStartState(BlockStartState):
    stateType: Incomplete
    def __init__(self) -> None: ...

class BlockEndState(ATNState):
    stateType: Incomplete
    startState: Incomplete
    def __init__(self) -> None: ...

class RuleStopState(ATNState):
    stateType: Incomplete
    def __init__(self) -> None: ...

class RuleStartState(ATNState):
    stateType: Incomplete
    stopState: Incomplete
    isPrecedenceRule: bool
    def __init__(self) -> None: ...

class PlusLoopbackState(DecisionState):
    stateType: Incomplete
    def __init__(self) -> None: ...

class PlusBlockStartState(BlockStartState):
    stateType: Incomplete
    loopBackState: Incomplete
    def __init__(self) -> None: ...

class StarBlockStartState(BlockStartState):
    stateType: Incomplete
    def __init__(self) -> None: ...

class StarLoopbackState(ATNState):
    stateType: Incomplete
    def __init__(self) -> None: ...

class StarLoopEntryState(DecisionState):
    stateType: Incomplete
    loopBackState: Incomplete
    isPrecedenceDecision: Incomplete
    def __init__(self) -> None: ...

class LoopEndState(ATNState):
    stateType: Incomplete
    loopBackState: Incomplete
    def __init__(self) -> None: ...

class TokensStartState(DecisionState):
    stateType: Incomplete
    def __init__(self) -> None: ...



from _typeshed import Incomplete
from typing import Any

from .base import BaseEndpoint as BaseEndpoint

log: Any

class ResourceEndpoint(BaseEndpoint):
    def validate_protected_resource_request(
        self,
        uri,
        http_method: str = "GET",
        body: Incomplete | None = None,
        headers: Incomplete | None = None,
        realms: Incomplete | None = None,
    ): ...



from _typeshed import Incomplete

class ExchangeRateQuoteGateway:
    gateway: Incomplete
    config: Incomplete
    graphql_client: Incomplete
    def __init__(self, gateway, graphql_client: Incomplete | None = None) -> None: ...
    exchange_rate_quote_payload: Incomplete
    def generate(self, request): ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class Netherlands(WesternCalendar):
    include_good_friday: ClassVar[bool]
    include_easter_sunday: ClassVar[bool]
    include_easter_monday: ClassVar[bool]
    include_ascension: ClassVar[bool]
    include_whit_sunday: ClassVar[bool]
    include_whit_monday: ClassVar[bool]
    include_boxing_day: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete
    include_carnival: Incomplete
    def __init__(self, include_carnival: bool = False) -> None: ...
    def get_king_queen_day(self, year): ...
    def get_carnival_days(self, year): ...
    def get_variable_days(self, year): ...

FALL_HOLIDAYS_EARLY_REGIONS: Incomplete
SPRING_HOLIDAYS_EARLY_REGIONS: Incomplete
SUMMER_HOLIDAYS_EARLY_REGIONS: Incomplete
SUMMER_HOLIDAYS_LATE_REGIONS: Incomplete

class NetherlandsWithSchoolHolidays(Netherlands):
    region: Incomplete
    carnival_instead_of_spring: Incomplete

    def __init__(self, region, carnival_instead_of_spring: bool = False, **kwargs) -> None: ...
    def get_fall_holidays(self, year): ...
    def get_christmas_holidays(self, year): ...
    def get_spring_holidays(self, year): ...
    def get_carnival_holidays(self, year): ...
    def get_may_holidays(self, year): ...
    def get_summer_holidays(self, year): ...
    def get_variable_days(self, year): ...



from typing import ClassVar

from ..core import WesternCalendar

class Ireland(WesternCalendar):
    include_easter_monday: ClassVar[bool]
    include_boxing_day: ClassVar[bool]
    boxing_day_label: ClassVar[str]
    shift_new_years_day: ClassVar[bool]
    def get_june_holiday(self, year): ...
    def get_august_holiday(self, year): ...
    include_whit_monday: ClassVar[bool]
    def get_variable_days(self, year): ...



from _typeshed import Incomplete
from collections.abc import Generator
from typing import ClassVar

__all__ = ["forest_str", "generate_network_text", "write_network_text"]

class _AsciiBaseGlyphs:
    empty: ClassVar[str]
    newtree_last: ClassVar[str]
    newtree_mid: ClassVar[str]
    endof_forest: ClassVar[str]
    within_forest: ClassVar[str]
    within_tree: ClassVar[str]

class AsciiDirectedGlyphs(_AsciiBaseGlyphs):
    last: ClassVar[str]
    mid: ClassVar[str]
    backedge: ClassVar[str]

class AsciiUndirectedGlyphs(_AsciiBaseGlyphs):
    last: ClassVar[str]
    mid: ClassVar[str]
    backedge: ClassVar[str]

class _UtfBaseGlyphs:
    empty: ClassVar[str]
    newtree_last: ClassVar[str]
    newtree_mid: ClassVar[str]
    endof_forest: ClassVar[str]
    within_forest: ClassVar[str]
    within_tree: ClassVar[str]

class UtfDirectedGlyphs(_UtfBaseGlyphs):
    last: ClassVar[str]
    mid: ClassVar[str]
    backedge: ClassVar[str]

class UtfUndirectedGlyphs(_UtfBaseGlyphs):
    last: ClassVar[str]
    mid: ClassVar[str]
    backedge: ClassVar[str]

def generate_network_text(
    graph,
    with_labels: bool = True,
    sources: Incomplete | None = None,
    max_depth: Incomplete | None = None,
    ascii_only: bool = False,
    vertical_chains: bool = False,
) -> Generator[Incomplete, None, Incomplete]: ...
def write_network_text(
    graph,
    path: Incomplete | None = None,
    with_labels: bool = True,
    sources: Incomplete | None = None,
    max_depth: Incomplete | None = None,
    ascii_only: bool = False,
    end: str = "\n",
    vertical_chains=False,
) -> None: ...
def forest_str(
    graph, with_labels: bool = True, sources: Incomplete | None = None, write: Incomplete | None = None, ascii_only: bool = False
): ...



from _typeshed import Incomplete
from abc import abstractmethod
from collections.abc import MutableMapping
from typing import Any

class SequenceGenerator:
    length: Any
    requested_entropy: str
    rng: Any
    @property
    @abstractmethod
    def symbol_count(self) -> int: ...
    def __init__(
        self, entropy: Incomplete | None = None, length: Incomplete | None = None, rng: Incomplete | None = None, **kwds
    ) -> None: ...
    @property
    def entropy_per_symbol(self) -> float: ...
    @property
    def entropy(self) -> float: ...
    def __next__(self) -> None: ...
    def __call__(self, returns: Incomplete | None = None): ...
    def __iter__(self): ...

default_charsets: Any

class WordGenerator(SequenceGenerator):
    charset: str
    chars: Any
    def __init__(self, chars: Incomplete | None = None, charset: Incomplete | None = None, **kwds) -> None: ...
    @property
    def symbol_count(self): ...
    def __next__(self): ...

def genword(entropy: Incomplete | None = None, length: Incomplete | None = None, returns: Incomplete | None = None, **kwds): ...

class WordsetDict(MutableMapping[Any, Any]):
    paths: Any
    def __init__(self, *args, **kwds) -> None: ...
    def __getitem__(self, key): ...
    def set_path(self, key, path) -> None: ...
    def __setitem__(self, key, value) -> None: ...
    def __delitem__(self, key) -> None: ...
    def __iter__(self): ...
    def __len__(self) -> int: ...
    def __contains__(self, key): ...

default_wordsets: Any

class PhraseGenerator(SequenceGenerator):
    wordset: str
    words: Any
    sep: str
    def __init__(
        self, wordset: Incomplete | None = None, words: Incomplete | None = None, sep: Incomplete | None = None, **kwds
    ) -> None: ...
    @property
    def symbol_count(self): ...
    def __next__(self): ...

def genphrase(entropy: Incomplete | None = None, length: Incomplete | None = None, returns: Incomplete | None = None, **kwds): ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def girvan_newman(G, most_valuable_edge: Incomplete | None = None) -> Generator[Incomplete, None, Incomplete]: ...



from collections.abc import Callable, Iterable
from typing import Any, TypeVar
from typing_extensions import ParamSpec, Self

from gevent.greenlet import Greenlet
from gevent.queue import UnboundQueue

_T = TypeVar("_T")
_P = ParamSpec("_P")

# this matches builtins.map to some degree, but since it is an non-public API type that just gets
# returned by some public API functions, we don't bother adding a whole bunch of overloads to handle
# the case of 1-n Iterables being passed in and just go for the fully unsafe signature
# we do the crazy overloads instead in the functions that create these objects
class IMapUnordered(Greenlet[_P, _T]):
    finished: bool
    # it may contain an undocumented Failure object
    queue: UnboundQueue[_T | object]
    def __init__(self, func: Callable[_P, _T], iterable: Iterable[Any], spawn: Callable[_P, Greenlet[_P, _T]]) -> None: ...
    def __iter__(self) -> Self: ...
    def __next__(self) -> _T: ...

class IMap(IMapUnordered[_P, _T]):
    index: int



from _typeshed import Incomplete
from typing import Any

from oauthlib.oauth2.rfc6749.tokens import TokenBase as TokenBase

class JWTToken(TokenBase):
    request_validator: Any
    token_generator: Any
    refresh_token_generator: Any
    expires_in: Any
    def __init__(
        self,
        request_validator: Incomplete | None = None,
        token_generator: Incomplete | None = None,
        expires_in: Incomplete | None = None,
        refresh_token_generator: Incomplete | None = None,
    ) -> None: ...
    def create_token(self, request, refresh_token: bool = False): ...
    def validate_request(self, request): ...
    def estimate_type(self, request): ...



from _typeshed import Incomplete

from antlr4.InputStream import InputStream as InputStream
from antlr4.ParserRuleContext import ParserRuleContext as ParserRuleContext
from antlr4.Recognizer import Recognizer as Recognizer

class UnsupportedOperationException(Exception):
    def __init__(self, msg: str) -> None: ...

class IllegalStateException(Exception):
    def __init__(self, msg: str) -> None: ...

class CancellationException(IllegalStateException):
    def __init__(self, msg: str) -> None: ...

class RecognitionException(Exception):
    message: Incomplete
    recognizer: Incomplete
    input: Incomplete
    ctx: Incomplete
    offendingToken: Incomplete
    offendingState: int
    def __init__(
        self,
        message: str | None = None,
        recognizer: Recognizer | None = None,
        input: InputStream | None = None,
        ctx: Incomplete | None = None,
    ) -> None: ...
    def getExpectedTokens(self): ...

class LexerNoViableAltException(RecognitionException):
    startIndex: Incomplete
    deadEndConfigs: Incomplete
    message: str
    def __init__(self, lexer, input: InputStream, startIndex: int, deadEndConfigs) -> None: ...

class NoViableAltException(RecognitionException):
    deadEndConfigs: Incomplete
    startToken: Incomplete
    offendingToken: Incomplete
    def __init__(
        self,
        recognizer,
        input: Incomplete | None = None,
        startToken: Incomplete | None = None,
        offendingToken: Incomplete | None = None,
        deadEndConfigs: Incomplete | None = None,
        ctx: ParserRuleContext | None = None,
    ) -> None: ...

class InputMismatchException(RecognitionException):
    offendingToken: Incomplete
    def __init__(self, recognizer) -> None: ...

class FailedPredicateException(RecognitionException):
    ruleIndex: Incomplete
    predicateIndex: Incomplete
    predicate: Incomplete
    offendingToken: Incomplete
    def __init__(self, recognizer, predicate: str | None = None, message: str | None = None) -> None: ...
    def formatMessage(self, predicate: str, message: str): ...

class ParseCancellationException(CancellationException): ...



from _typeshed import Incomplete
from types import TracebackType
from typing_extensions import Self

from influxdb_client.client._base import _BaseClient
from influxdb_client.client.delete_api_async import DeleteApiAsync
from influxdb_client.client.query_api import QueryOptions
from influxdb_client.client.query_api_async import QueryApiAsync
from influxdb_client.client.write_api import PointSettings
from influxdb_client.client.write_api_async import WriteApiAsync

logger: Incomplete

class InfluxDBClientAsync(_BaseClient):
    api_client: Incomplete
    def __init__(
        self,
        url: str,
        token: str | None = None,
        org: str | None = None,
        debug: bool | None = None,
        timeout: int = 10000,
        enable_gzip: bool = False,
        *,
        verify_ssl: bool = ...,
        ssl_ca_cert: Incomplete | None = ...,
        cert_file: Incomplete | None = ...,
        cert_key_file: Incomplete | None = ...,
        cert_key_password: Incomplete | None = ...,
        ssl_context: Incomplete | None = ...,
        proxy: Incomplete | None = ...,
        proxy_headers: Incomplete | None = ...,
        connection_pool_maxsize: int = ...,
        username: Incomplete | None = ...,
        password: Incomplete | None = ...,
        auth_basic: bool = ...,
        retries: bool | Incomplete = ...,
        profilers: Incomplete | None = ...,
    ) -> None: ...
    async def __aenter__(self) -> Self: ...
    async def __aexit__(
        self, exc_type: type[BaseException] | None, exc: BaseException | None, tb: TracebackType | None
    ) -> None: ...
    async def close(self) -> None: ...
    @classmethod
    def from_config_file(
        cls, config_file: str = "config.ini", debug: Incomplete | None = None, enable_gzip: bool = False, **kwargs
    ): ...
    @classmethod
    def from_env_properties(cls, debug: Incomplete | None = None, enable_gzip: bool = False, **kwargs): ...
    async def ping(self) -> bool: ...
    async def version(self) -> str: ...
    async def build(self) -> str: ...
    def query_api(self, query_options: QueryOptions = ...) -> QueryApiAsync: ...
    def write_api(self, point_settings: PointSettings = ...) -> WriteApiAsync: ...
    def delete_api(self) -> DeleteApiAsync: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def hnm_harary_graph(n, m, create_using: Incomplete | None = None): ...
@_dispatch
def hkn_harary_graph(k, n, create_using: Incomplete | None = None): ...



from networkx.exception import NetworkXException
from networkx.utils.backends import _dispatch

class NotATree(NetworkXException): ...

@_dispatch
def to_nested_tuple(T, root, canonical_form: bool = False): ...
@_dispatch
def from_nested_tuple(sequence, sensible_relabeling: bool = False): ...
@_dispatch
def to_prufer_sequence(T): ...
@_dispatch
def from_prufer_sequence(sequence): ...



from _typeshed import ReadableBuffer
from collections.abc import Callable
from hashlib import _Hash
from typing import Any

from .base import Key

def get_random_bytes(num_bytes: int) -> bytes: ...

class HMACKey(Key):
    HASHES: dict[str, Callable[[bytes], _Hash]]
    prepared_key: bytes
    def __init__(
        self,
        # explicitly checks for key_data as dict instance, instead of a Mapping
        key: str | bytes | dict[str, Any],
        algorithm: str,
    ) -> None: ...
    def sign(self, msg: ReadableBuffer | None) -> bytes: ...
    def verify(self, msg: ReadableBuffer | None, sig: str | bytes) -> bool: ...
    def to_dict(self) -> dict[str, Any]: ...



from typing_extensions import deprecated

class StyleProxy:
    def __init__(self, target) -> None: ...
    def __getattr__(self, attr: str): ...
    def __setattr__(self, attr: str, value) -> None: ...
    def __copy__(self): ...
    def __add__(self, other): ...
    @deprecated("Use copy(obj) or cell.obj = cell.obj + other")
    def copy(self, **kw): ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



import dataclasses
from _typeshed import Incomplete
from collections.abc import Generator
from dataclasses import dataclass
from typing import overload
from typing_extensions import Self

from .drawing import DeviceGray, DeviceRGB, Number
from .enums import TextEmphasis
from .syntax import PDFObject

# Only defined if harfbuzz is installed.
class HarfBuzzFont(Incomplete):  # derives from uharfbuzz.Font
    def __deepcopy__(self, _memo: object) -> Self: ...

@dataclass
class FontFace:
    family: str | None
    emphasis: TextEmphasis | None
    size_pt: int | None
    color: DeviceGray | DeviceRGB | None
    fill_color: DeviceGray | DeviceRGB | None

    def __init__(
        self,
        family: str | None = None,
        emphasis: Incomplete | None = None,
        size_pt: int | None = None,
        color: int | tuple[Number, Number, Number] | DeviceGray | DeviceRGB | None = None,
        fill_color: int | tuple[Number, Number, Number] | DeviceGray | DeviceRGB | None = None,
    ) -> None: ...

    replace = dataclasses.replace

    @overload
    @staticmethod
    def combine(default_style: None, override_style: None) -> None: ...  # type: ignore[misc]
    @overload
    @staticmethod
    def combine(default_style: FontFace | None, override_style: FontFace | None) -> FontFace: ...

class _FontMixin:
    i: int
    type: str
    name: str
    up: int
    ut: int
    cw: int
    fontkey: str
    emphasis: TextEmphasis
    def encode_text(self, text: str): ...

class CoreFont(_FontMixin):
    def __init__(self, fpdf, fontkey: str, style: int) -> None: ...
    def get_text_width(self, text: str, font_size_pt: int, _): ...

class TTFFont(_FontMixin):
    ttffile: Incomplete
    ttfont: Incomplete
    scale: Incomplete
    desc: Incomplete
    cmap: Incomplete
    glyph_ids: Incomplete
    missing_glyphs: Incomplete
    subset: Incomplete
    hbfont: HarfBuzzFont | None  # Not always defined.
    def __init__(self, fpdf, font_file_path, fontkey: str, style: int) -> None: ...
    def close(self) -> None: ...
    def get_text_width(self, text: str, font_size_pt: int, text_shaping_parms): ...
    def shaped_text_width(self, text: str, font_size_pt: int, text_shaping_parms): ...
    def perform_harfbuzz_shaping(self, text: str, font_size_pt: int, text_shaping_parms): ...
    def shape_text(self, text: str, font_size_pt: int, text_shaping_parms): ...

class PDFFontDescriptor(PDFObject):
    type: Incomplete
    ascent: Incomplete
    descent: Incomplete
    cap_height: Incomplete
    flags: Incomplete
    font_b_box: Incomplete
    italic_angle: Incomplete
    stem_v: Incomplete
    missing_width: Incomplete
    font_name: Incomplete
    def __init__(self, ascent, descent, cap_height, flags, font_b_box, italic_angle, stem_v, missing_width) -> None: ...

class Glyph:
    glyph_id: int
    unicode: tuple[Incomplete, ...]
    glyph_name: str
    glyph_width: int
    def __hash__(self): ...
    def __init__(self, glyph_id, unicode, glyph_name, glyph_width) -> None: ...
    def __lt__(self, other): ...
    def __gt__(self, other): ...
    def __le__(self, other): ...
    def __ge__(self, other): ...

    __match_args__ = ("glyph_id", "unicode", "glyph_name", "glyph_width")

class SubsetMap:
    font: TTFFont
    def __init__(self, font: TTFFont, identities: list[int]) -> None: ...
    def __len__(self) -> int: ...
    def items(self) -> Generator[Incomplete, None, None]: ...
    def pick(self, unicode: int): ...
    def pick_glyph(self, glyph): ...
    def get_glyph(
        self,
        glyph: Incomplete | None = None,
        unicode: Incomplete | None = None,
        glyph_name: Incomplete | None = None,
        glyph_width: Incomplete | None = None,
    ) -> Glyph: ...
    def get_all_glyph_names(self): ...

CORE_FONTS: dict[str, str]
COURIER_FONT: dict[str, int]
CORE_FONTS_CHARWIDTHS: dict[str, dict[str, int]]



from _typeshed import Incomplete

import qrcode.image.base

class PilImage(qrcode.image.base.BaseImage):
    kind: str
    fill_color: Incomplete
    def new_image(self, **kwargs): ...
    def drawrect(self, row, col) -> None: ...
    def save(self, stream, format: Incomplete | None = None, **kwargs) -> None: ...  # type: ignore[override]
    def __getattr__(self, name): ...



from _typeshed import Incomplete

from influxdb_client.domain.view_properties import ViewProperties

class MarkdownViewProperties(ViewProperties):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, type: Incomplete | None = None, shape: Incomplete | None = None, note: Incomplete | None = None
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def shape(self): ...
    @shape.setter
    def shape(self, shape) -> None: ...
    @property
    def note(self): ...
    @note.setter
    def note(self, note) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class ASTResponse:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, ast: Incomplete | None = None) -> None: ...
    @property
    def ast(self): ...
    @ast.setter
    def ast(self, ast) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
